<?php

namespace Longman\TelegramBot\Entities;

/**
 * Class BotShortDescription
 *
 * This entity represents the bot's short description.
 *
 * @link https://core.telegram.org/bots/api#botshortdescription
 *
 * @method string getShortDescription() The bot's short description
 */
class BotShortDescription extends Entity
{

}
