<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    67320 => 'Brunei Muara',
    67321 => 'Brunei Muara',
    673220 => 'Brunei Muara',
    673221 => 'Brunei Muara',
    673222 => 'Brunei Muara',
    673223 => 'Brunei Muara',
    673224 => 'Brunei Muara',
    673225 => 'Brunei Muara',
    673226 => 'Brunei Muara',
    673227 => 'Brunei Muara',
    67323 => 'Brunei Muara',
    67324 => 'Brunei Muara',
    67325 => 'Brunei Muara',
    67326 => 'Brunei Muara',
    67327 => 'Brunei Muara',
    67328 => 'Brunei Muara',
    67329 => 'Brunei Muara',
    6733 => 'Beliat',
    6734 => 'Tutong',
    67350 => 'Temburong',
    67351 => 'Temburong',
    67352 => 'Temburong',
    67355 => 'Temburong',
    67356 => 'Temburong',
    67357 => 'Temburong',
    67358 => 'Temburong',
    67359 => 'Temburong',
];
