<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    25821 => 'Maputo',
    25823 => 'Beira',
    25824 => 'Quelimane',
    258251 => 'Manica',
    258252 => 'Tete',
    25826 => 'Nampula',
    258271 => 'Lichinga',
    258272 => 'Pemba',
    258281 => 'Chokwe',
    258282 => 'Xai-Xai',
    25829 => 'Inhambane',
];
