<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    24491 => 'Movicel',
    24492 => 'UNITEL',
    24493 => 'UNITEL',
    24494 => 'UNITEL',
    24495 => 'Africell',
    24496 => 'Africell',
    24497 => 'UNITEL',
    24499 => 'Movicel',
];
