<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    269760 => 'Domoni',
    269761 => 'Mutsamudu',
    269762 => 'Mohéli',
    269763 => 'Moroni',
    269767 => 'Mbéni',
    269768 => 'Mitsamiouli',
    269769 => 'Foumbouni',
    269770 => 'Domoni',
    269771 => 'Mutsamudu',
    269772 => 'Mohéli',
    269773 => 'Moroni',
    269774 => 'Moroni',
    269775 => 'Moroni',
    269777 => 'Mbéni',
    269778 => 'Mitsamiouli',
    269779 => 'Foumbouni',
];
