<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    249153 => 'Khartoum',
    249155 => 'Khartoum North',
    249156 => 'Khartoum Rural',
    249157 => 'Omdurman',
    249183 => 'Khartoum',
    249185 => 'Khartoum North',
    249186 => 'Khartoum Rural',
    249187 => 'Omdurman',
];
