<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    35222 => 'Luxemburg',
    35223 => 'Bad Mondorf',
    352240 => 'Luxemburg',
    352241 => 'Luxemburg',
    352242 => 'Luxemburg',
    3522421 => 'Weicherdingen',
    3522423 => 'Bad Mondorf',
    3522427 => 'Belair, Luxemburg',
    3522429 => 'Luxemburg/Kockelscheuer',
    3522430 => 'Kanton Capellen/Kehlen',
    3522431 => 'Bartringen',
    3522432 => 'Lintgen/Kanton Mersch/Steinfort',
    3522433 => 'Walferdingen',
    3522434 => 'Rammeldingen/Senningerberg',
    3522435 => 'Sandweiler/Mutfort/Roodt-sur-Syre',
    3522436 => 'Hesperingen/Kockelscheuer/Roeser',
    3522437 => 'Leudelingen/Ehlingen/Monnerich',
    3522438 => 'Luxemburg',
    3522439 => 'Windhof/Steinfort',
    3522440 => 'Howald',
    3522441 => 'Luxemburg',
    3522442 => 'Plateau de Kirchberg',
    3522443 => 'Findel/Kirchberg',
    3522444 => 'Luxemburg',
    3522445 => 'Diedrich',
    3522446 => 'Luxemburg',
    3522447 => 'Lintgen',
    3522448 => 'Contern/Foetz',
    3522449 => 'Howald',
    3522450 => 'Bascharage/Petingen/Rodingen',
    3522451 => 'Düdelingen/Bettemburg/Livingen',
    3522452 => 'Düdelingen',
    3522453 => 'Esch-sur-Alzette',
    3522454 => 'Esch-sur-Alzette',
    3522455 => 'Esch-sur-Alzette/Monnerich',
    3522456 => 'Rümelingen',
    3522457 => 'Esch-sur-Alzette/Schifflingen',
    3522458 => 'Soleuvre/Differdingen',
    3522459 => 'Soleuvre',
    352246 => 'Luxemburg',
    3522467 => 'Düdelingen',
    3522470 => 'Luxemburg',
    3522471 => 'Betzdorf',
    3522472 => 'Echternach',
    3522473 => 'Rosport',
    3522474 => 'Wasserbillig',
    3522475 => 'Distrikt Grevenmacher-sur-Moselle',
    3522476 => 'Wormeldingen',
    3522477 => 'Luxemburg',
    3522478 => 'Junglinster',
    3522479 => 'Berdorf/Consdorf',
    3522480 => 'Diekirch',
    3522481 => 'Ettelbrück/Reckange-sur-Mess',
    3522482 => 'Luxemburg',
    3522483 => 'Vianden',
    3522484 => 'Han/Lesse',
    3522485 => 'Bissen/Roost',
    3522486 => 'Luxemburg',
    3522487 => 'Fels',
    3522488 => 'Mertzig/Wahl',
    3522489 => 'Luxemburg',
    352249 => 'Luxemburg',
    3522492 => 'Kanton Clerf/Fischbach/Hosingen',
    3522495 => 'Wiltz',
    3522497 => 'Huldingen',
    3522499 => 'Ulflingen',
    35225 => 'Luxemburg',
    3522621 => 'Weicherdingen',
    3522622 => 'Luxemburg',
    3522623 => 'Bad Mondorf',
    3522625 => 'Luxemburg',
    3522627 => 'Belair, Luxemburg',
    3522628 => 'Luxemburg',
    3522629 => 'Luxemburg/Kockelscheuer',
    3522630 => 'Kanton Capellen/Kehlen',
    3522631 => 'Bartringen',
    3522632 => 'Lintgen/Kanton Mersch/Steinfort',
    3522633 => 'Walferdingen',
    3522634 => 'Rammeldingen/Senningerberg',
    3522635 => 'Sandweiler/Mutfort/Roodt-sur-Syre',
    3522636 => 'Hesperingen/Kockelscheuer/Roeser',
    3522637 => 'Leudelingen/Ehlingen/Monnerich',
    3522639 => 'Windhof/Steinfort',
    3522640 => 'Howald',
    3522642 => 'Plateau de Kirchberg',
    3522643 => 'Findel/Kirchberg',
    3522645 => 'Diedrich',
    3522647 => 'Lintgen',
    3522648 => 'Contern/Foetz',
    3522649 => 'Howald',
    3522650 => 'Bascharage/Petingen/Rodingen',
    3522651 => 'Düdelingen/Bettemburg/Livingen',
    3522652 => 'Düdelingen',
    3522653 => 'Esch-sur-Alzette',
    3522654 => 'Esch-sur-Alzette',
    3522655 => 'Esch-sur-Alzette/Monnerich',
    3522656 => 'Rümelingen',
    3522657 => 'Esch-sur-Alzette/Schifflingen',
    3522658 => 'Soleuvre/Differdingen',
    3522659 => 'Soleuvre',
    3522667 => 'Düdelingen',
    3522671 => 'Betzdorf',
    3522672 => 'Echternach',
    3522673 => 'Rosport',
    3522674 => 'Wasserbillig',
    3522675 => 'Distrikt Grevenmacher-sur-Moselle',
    3522676 => 'Wormeldingen',
    3522678 => 'Junglinster',
    3522679 => 'Berdorf/Consdorf',
    3522680 => 'Diekirch',
    3522681 => 'Ettelbrück/Reckange-sur-Mess',
    3522683 => 'Vianden',
    3522684 => 'Han/Lesse',
    3522685 => 'Bissen/Roost',
    3522687 => 'Fels',
    3522688 => 'Mertzig/Wahl',
    3522692 => 'Kanton Clerf/Fischbach/Hosingen',
    3522695 => 'Wiltz',
    3522697 => 'Huldingen',
    3522699 => 'Ulflingen',
    3522721 => 'Weicherdingen',
    3522722 => 'Luxemburg',
    3522723 => 'Bad Mondorf',
    3522725 => 'Luxemburg',
    3522727 => 'Belair, Luxemburg',
    3522728 => 'Luxemburg',
    3522729 => 'Luxemburg/Kockelscheuer',
    3522730 => 'Kanton Capellen/Kehlen',
    3522731 => 'Bartringen',
    3522732 => 'Lintgen/Kanton Mersch/Steinfort',
    3522733 => 'Walferdingen',
    3522734 => 'Rammeldingen/Senningerberg',
    3522735 => 'Sandweiler/Mutfort/Roodt-sur-Syre',
    3522736 => 'Hesperingen/Kockelscheuer/Roeser',
    3522737 => 'Leudelingen/Ehlingen/Monnerich',
    3522739 => 'Windhof/Steinfort',
    3522740 => 'Howald',
    3522742 => 'Plateau de Kirchberg',
    3522743 => 'Findel/Kirchberg',
    3522745 => 'Diedrich',
    3522747 => 'Lintgen',
    3522748 => 'Contern/Foetz',
    3522749 => 'Howald',
    3522750 => 'Bascharage/Petingen/Rodingen',
    3522751 => 'Düdelingen/Bettemburg/Livingen',
    3522752 => 'Düdelingen',
    3522753 => 'Esch-sur-Alzette',
    3522754 => 'Esch-sur-Alzette',
    3522755 => 'Esch-sur-Alzette/Monnerich',
    3522756 => 'Rümelingen',
    3522757 => 'Esch-sur-Alzette/Schifflingen',
    3522758 => 'Soleuvre/Differdingen',
    3522759 => 'Soleuvre',
    3522767 => 'Düdelingen',
    3522771 => 'Betzdorf',
    3522772 => 'Echternach',
    3522773 => 'Rosport',
    3522774 => 'Wasserbillig',
    3522775 => 'Distrikt Grevenmacher-sur-Moselle',
    3522776 => 'Wormeldingen',
    3522778 => 'Junglinster',
    3522779 => 'Berdorf/Consdorf',
    3522780 => 'Diekirch',
    3522781 => 'Ettelbrück/Reckange-sur-Mess',
    3522783 => 'Vianden',
    3522784 => 'Han/Lesse',
    3522785 => 'Bissen/Roost',
    3522787 => 'Fels',
    3522788 => 'Mertzig/Wahl',
    3522792 => 'Kanton Clerf/Fischbach/Hosingen',
    3522795 => 'Wiltz',
    3522797 => 'Huldingen',
    3522799 => 'Ulflingen',
    35228 => 'Luxemburg',
    35229 => 'Luxemburg',
    35230 => 'Kanton Capellen/Kehlen',
    35231 => 'Bartringen',
    35232 => 'Kanton Mersch',
    35233 => 'Walferdingen',
    35234 => 'Rammeldingen/Senningerberg',
    35235 => 'Sandweiler/Mutfort/Roodt-sur-Syre',
    35236 => 'Hesperingen/Kockelscheuer/Roeser',
    35237 => 'Leudelingen/Ehlingen/Monnerich',
    35239 => 'Windhof/Steinfort',
    35240 => 'Howald',
    35241 => 'Luxemburg',
    35242 => 'Plateau de Kirchberg',
    35243 => 'Findel/Kirchberg',
    35244 => 'Luxemburg',
    35245 => 'Diedrich',
    35246 => 'Luxemburg',
    35247 => 'Lintgen',
    35248 => 'Contern/Foetz',
    35249 => 'Howald',
    35250 => 'Bascharage/Petingen/Rodingen',
    35251 => 'Düdelingen/Bettemburg/Livingen',
    35252 => 'Düdelingen',
    35253 => 'Esch-sur-Alzette',
    35254 => 'Esch-sur-Alzette',
    35255 => 'Esch-sur-Alzette/Monnerich',
    35256 => 'Rümelingen',
    35257 => 'Esch-sur-Alzette/Schifflingen',
    35258 => 'Differdingen',
    35259 => 'Soleuvre',
    35271 => 'Betzdorf',
    35272 => 'Echternach',
    35273 => 'Rosport',
    35274 => 'Wasserbillig',
    35275 => 'Distrikt Grevenmacher',
    35276 => 'Wormeldingen',
    35278 => 'Junglinster',
    35279 => 'Berdorf/Consdorf',
    35280 => 'Diekirch',
    35281 => 'Ettelbrück',
    35283 => 'Vianden',
    35284 => 'Han/Lesse',
    35285 => 'Bissen/Roost',
    35287 => 'Fels',
    35288 => 'Mertzig/Wahl',
    35292 => 'Kanton Clerf/Fischbach/Hosingen',
    35295 => 'Wiltz',
    35297 => 'Huldingen',
    35299 => 'Ulflingen',
];
