<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    21112 => 'Sudatel Group',
    21191 => 'Zain',
    21192 => 'MTN',
    21195 => 'Network of the World',
    21197 => 'Gemtel',
    21198 => 'Digitel',
    21199 => 'MTN',
];
