<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    9320 => 'کابل',
    9321 => 'پروان',
    9322 => 'کاپیسا',
    9323 => 'بامیان',
    9324 => 'وردک',
    9325 => 'لوگر',
    9326 => 'دایکندی',
    9327 => 'خوست',
    9328 => 'پنجشیر',
    9330 => 'قندهار',
    9331 => 'غزنی',
    9332 => 'ارزگان',
    9333 => 'زابل',
    9334 => 'هلمند',
    9340 => 'هرات',
    9341 => 'بادغیس',
    9342 => 'غور',
    9343 => 'فراه',
    9344 => 'نیمروز',
    9350 => 'بلخ',
    9351 => 'قندوز',
    9352 => 'بدخشان',
    9353 => 'تخار',
    9354 => 'جوزجان',
    9355 => 'سمنگان',
    9356 => 'سر پل',
    9357 => 'فاریاب',
    9358 => 'بغلان',
    9360 => 'ننگرهار',
    9361 => 'نورستان',
    9362 => 'کنرها',
    9363 => 'لغمان',
    9364 => 'پکتیا',
    9365 => 'پکتیکا',
];
