<?php
namespace Aws\OpsWorksCM\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS OpsWorks for Chef Automate** service.
 */
class OpsWorksCMException extends AwsException {}
