<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    9752 => 'Thimphu',
    9753 => 'Trongsa',
    9754 => 'Trashigang',
    9755 => 'Phuentsholing',
    9756 => 'Gelephu',
    97572 => 'Samdrup Jongkhar',
    97574 => 'Samdrup Jongkhar',
    97576 => 'Samdrup Jongkhar',
    9758 => 'Paro',
];
