<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    37410 => 'Ереван/Джрвеж',
    37411 => 'Ереван',
    37412 => 'Ереван',
    37415 => 'Ереван',
    3742220 => 'Абовян/Акунк/Бюрегаван/Нор Гюх/Верин Птхни, Котайк',
    3742221 => 'Абовян/Акунк/Бюрегаван/Нор Гюх/Верин Птхни, Котайк',
    3742222 => 'Абовян, Котайк',
    3742223 => 'Абовян, Котайк',
    3742224 => 'Абовян, Котайк',
    3742225 => 'Абовян/Арзни/Ариндж/Гехашен, Котайк',
    3742226 => 'Абовян, Котайк',
    3742227 => 'Гарни/Абовян, Котайк',
    3742228 => 'Абовян/Акунк/Бюрегаван/Нор Гюх/Верин Птхни, Котайк',
    37422281 => 'Абовян/Арзни/Ариндж/Гехашен, Котайк',
    37422290 => 'Маяковский, Котайк',
    37422291 => 'Балаовит/Камарис, Котайк',
    37422292 => 'Зовк/Абовян, Котайк',
    37422293 => 'Арамус, Котайк',
    37422294 => 'Арзни, Котайк',
    37422295 => 'Зовк/Абовян, Котайк',
    37422296 => 'Птхни, Котайк',
    37422297 => 'Гехашен, Котайк',
    37422298 => 'Ариндж, Котайк',
    37422299 => 'Котайк',
    3742230 => 'Анкаван/Раздан/Цахкадзор, Котайк',
    3742231 => 'Анкаван/Раздан/Цахкадзор, Котайк',
    3742232 => 'Раздан, Котайк',
    3742233 => 'Раздан, Котайк',
    3742234 => 'Раздан, Котайк',
    3742235 => 'Цахкадзор, Котайк',
    3742236 => 'Раздан, Котайк',
    37422370 => 'Раздан, Котайк',
    37422371 => 'Раздан, Котайк',
    37422372 => 'Раздан, Котайк',
    37422373 => 'Раздан, Котайк',
    37422374 => 'Раздан, Котайк',
    37422375 => 'Цахкадзор, Котайк',
    37422376 => 'Цахкадзор, Котайк',
    37422377 => 'Цахкадзор, Котайк',
    37422378 => 'Цахкадзор, Котайк',
    37422379 => 'Цахкадзор, Котайк',
    3742238 => 'Анкаван/Раздан/Цахкадзор, Котайк',
    374223810 => 'Раздан, Котайк',
    374223811 => 'Раздан, Котайк',
    374223812 => 'Раздан, Котайк',
    374223813 => 'Раздан, Котайк',
    374223814 => 'Раздан, Котайк',
    374223815 => 'Цахкадзор, Котайк',
    374223816 => 'Цахкадзор, Котайк',
    374223817 => 'Цахкадзор, Котайк',
    374223818 => 'Цахкадзор, Котайк',
    374223819 => 'Цахкадзор, Котайк',
    37422390 => 'Раздан, Котайк',
    37422391 => 'Лернанист, Котайк',
    37422392 => 'Раздан, Котайк',
    37422393 => 'Мехрадзор, Котайк',
    37422394 => 'Пюник, Котайк',
    37422395 => 'Раздан, Котайк',
    37422396 => 'Раздан, Котайк',
    37422397 => 'Солак, Котайк',
    37422398 => 'Бжни, Котайк',
    37422399 => 'Раздан, Котайк',
    3742240 => 'Канакераван/Нор Гехи/Нор Ачн/Егвард, Котайк',
    3742241 => 'Канакераван/Нор Гехи/Нор Ачн/Егвард, Котайк',
    3742242 => 'Егвард, Котайк',
    3742243 => 'Егвард, Котайк',
    3742244 => 'Нор Ачн, Котайк',
    3742245 => 'Егвард, Котайк',
    37422452 => 'Зовуни, Котайк',
    37422453 => 'Прошян, Котайк',
    37422454 => 'Аргел, Котайк',
    3742246 => 'Егвард, Котайк',
    3742247 => 'Егвард/Нор Ачн, Котайк',
    3742248 => 'Канакераван/Нор Гехи/Нор Ачн/Егвард, Котайк',
    374224810 => 'Егвард, Котайк',
    374224811 => 'Егвард, Котайк',
    374224812 => 'Егвард, Котайк',
    374224813 => 'Егвард, Котайк',
    374224814 => 'Егвард, Котайк',
    374224815 => 'Нор Ачн, Котайк',
    374224816 => 'Нор Ачн, Котайк',
    374224817 => 'Нор Ачн, Котайк',
    374224818 => 'Нор Ачн, Котайк',
    374224819 => 'Нор Ачн, Котайк',
    3742249 => 'Егвард, Котайк',
    374226 => 'Чаренцаван, Котайк',
    37422672 => 'Арзакан, Котайк',
    37422675 => 'Алапарс/Варданаванк, Котайк',
    3742310 => 'Эчмиадзин/Мусалер/Паракяр/Звартноц, Армавир',
    3742311 => 'Эчмиадзин/Мусалер/Паракяр/Звартноц, Армавир',
    3742312 => 'Эчмиадзин, Армавир',
    3742313 => 'Звартноц, Армавир',
    3742314 => 'Эчмиадзин, Армавир',
    3742315 => 'Эчмиадзин, Армавир',
    3742316 => 'Эчмиадзин, Армавир',
    3742317 => 'Звартноц, Армавир',
    3742318 => 'Эчмиадзин/Мусалер/Паракяр/Звартноц, Армавир',
    37423181 => 'Эчмиадзин, Армавир',
    374231817 => 'Звартноц, Армавир',
    374231818 => 'Звартноц, Армавир',
    374231819 => 'Звартноц, Армавир',
    37423190 => 'Баграмян, Армавир',
    37423191 => 'Ваче, Армавир',
    37423192 => 'Эчмиадзин, Армавир',
    37423193 => 'Эчмиадзин, Армавир',
    37423194 => 'Эчмиадзин, Армавир',
    37423195 => 'Норакерт, Армавир',
    37423196 => 'Эчмиадзин, Армавир',
    37423197 => 'Эчмиадзин, Армавир',
    37423198 => 'Джрарат, Армавир',
    37423199 => 'Хоронк, Армавир',
    3742320 => 'Ахцк/Аштарак/Карби/Ошакан, Арагацо́тн',
    3742321 => 'Ахцк/Аштарак/Карби/Ошакан, Арагацо́тн',
    3742322 => 'Аштарак, Арагацо́тн',
    3742323 => 'Аштарак, Арагацо́тн',
    3742324 => 'Аштарак/Бюракан/Оганаван, Арагацо́тн',
    3742325 => 'Ахцк/Аштарак/Карби/Ошакан, Арагацо́тн',
    3742326 => 'Аштарак, Арагацо́тн',
    3742327 => 'Ахцк/Аштарак/Карби/Ошакан, Арагацо́тн',
    3742328 => 'Ахцк/Аштарак/Карби/Ошакан, Арагацо́тн',
    37423281 => 'Аштарак/Бюракан/Оганаван, Арагацо́тн',
    3742329 => 'Аштарак, Арагацо́тн',
    37423290 => 'Оганаван, Арагацо́тн',
    37423294 => 'Бюракан, Арагацо́тн',
    3742330 => 'Баграмян/Лернагог, Армавир',
    3742331 => 'Баграмян/Лернагог, Армавир',
    3742332 => 'Баграмян, Армавир',
    3742333 => 'Баграмян/Мясникян, Армавир',
    3742334 => 'Баграмян/Лернагог, Армавир',
    3742335 => 'Баграмян/Лернагог, Армавир',
    3742336 => 'Баграмян, Армавир',
    3742337 => 'Баграмян, Армавир',
    37423374 => 'Мясникян, Армавир',
    37423375 => 'Каракерт, Армавир',
    37423376 => 'Даларик, Армавир',
    3742338 => 'Баграмян/Лернагог, Армавир',
    37423381 => 'Баграмян/Мясникян, Армавир',
    3742339 => 'Баграмян, Армавир',
    374234 => 'Арарат/Веди, Арарат',
    3742340 => 'Арарат/Веди/Воскетап, Арарат',
    3742341 => 'Арарат/Веди/Воскетап, Арарат',
    3742345 => 'Арарат/Веди/Воскетап, Арарат',
    374234510 => 'Веди, Арарат',
    374234511 => 'Веди, Арарат',
    374234512 => 'Веди, Арарат',
    374234513 => 'Веди, Арарат',
    374234514 => 'Веди, Арарат',
    374234515 => 'Арарат/Урцадзор, Арарат',
    374234516 => 'Арарат/Урцадзор, Арарат',
    374234517 => 'Арарат/Урцадзор, Арарат',
    374234518 => 'Арарат/Урцадзор, Арарат',
    374234519 => 'Арарат/Урцадзор, Арарат',
    37423470 => 'Веди, Арарат',
    37423471 => 'Веди, Арарат',
    37423472 => 'Веди, Арарат',
    37423473 => 'Веди, Арарат',
    37423474 => 'Веди, Арарат',
    37423475 => 'Арарат/Урцадзор, Арарат',
    37423476 => 'Арарат/Урцадзор, Арарат',
    37423477 => 'Арарат/Урцадзор, Арарат',
    37423478 => 'Арарат/Урцадзор, Арарат',
    37423479 => 'Арарат/Урцадзор, Арарат',
    37423481 => 'Айгаван, Арарат',
    37423486 => 'Урцадзор, Арарат',
    37423492 => 'Мартиросян, Арарат',
    37423497 => 'Покр Веди, Арарат',
    37423498 => 'Таперакан, Арарат',
    3742350 => 'Арташат/Айгезард/Далар/Кахцрашен/Мхчян/Шаумян, Арарат',
    3742351 => 'Арташат/Айгезард/Далар/Кахцрашен/Мхчян/Шаумян, Арарат',
    3742352 => 'Арташат, Арарат',
    3742353 => 'Арташат/Норашен, Арарат',
    3742354 => 'Арташат/Айгезард/Далар/Кахцрашен/Мхчян/Шаумян, Арарат',
    3742355 => 'Арташат, Арарат',
    3742356 => 'Арташат, Арарат',
    3742357 => 'Арташат, Арарат',
    3742358 => 'Арташат/Айгезард/Далар/Кахцрашен/Мхчян/Шаумян, Арарат',
    37423581 => 'Арташат/Норашен, Арарат',
    3742360 => 'Айнтап/Масис/Нор Харберд/Норабац, Арарат',
    3742361 => 'Айнтап/Масис/Нор Харберд/Норабац, Арарат',
    3742362 => 'Масис, Арарат',
    3742363 => 'Айнтап/Масис, Арарат',
    3742364 => 'Масис, Арарат',
    3742365 => 'Масис, Арарат',
    3742366 => 'Масис, Арарат',
    3742367 => 'Айнтап/Масис/Нор Харберд/Норабац, Арарат',
    3742368 => 'Айнтап/Масис/Нор Харберд/Норабац, Арарат',
    37423681 => 'Масис, Арарат',
    3742369 => 'Масис, Арарат',
    37423699 => 'Даштаван, Арарат',
    3742370 => 'Аракс/Армавир/Октембер/Ленухи/Мецамор/Зартонк, Армавир',
    3742371 => 'Аракс/Армавир/Октембер/Ленухи/Мецамор/Зартонк, Армавир',
    3742372 => 'Армавир',
    3742373 => 'Мецамор, Армавир',
    3742374 => 'Армавир',
    37423747 => 'Аракс/Армавир/Октембер/Ленухи/Мецамор/Зартонк, Армавир',
    37423748 => 'Аракс/Армавир/Октембер/Ленухи/Мецамор/Зартонк, Армавир',
    37423749 => 'Аракс/Армавир/Октембер/Ленухи/Мецамор/Зартонк, Армавир',
    3742375 => 'Армавир',
    3742376 => 'Армавир',
    3742377 => 'Армавир/Мргашат',
    37423771 => 'Армавир',
    37423772 => 'Мргашат, Армавир',
    37423779 => 'Бамбакашат, Армавир',
    3742378 => 'Аракс/Армавир/Октембер/Ленухи/Мецамор/Зартонк, Армавир',
    37423781 => 'Армавир',
    3742379 => 'Армавир/Налбандяна',
    37423792 => 'Налбандяна, Армавир',
    37423794 => 'Маргара, Армавир',
    37423796 => 'Тандзут, Армавир',
    37423798 => 'Шенаван, Армавир',
    374238 => 'Арарат/Авшар/Суренаван/Ерасх',
    3742420 => 'Маралик/Сарнахбюр, Ширакский',
    3742421 => 'Маралик/Сарнахбюр, Ширакский',
    3742422 => 'Маралик, Ширакский',
    3742423 => 'Маралик, Ширакский',
    37424231 => 'Сарнахбюр, Ширакский',
    3742424 => 'Маралик, Ширакский',
    3742425 => 'Маралик/Сарнахбюр, Ширакский',
    3742426 => 'Маралик, Ширакский',
    3742427 => 'Маралик/Сарнахбюр, Ширакский',
    3742428 => 'Маралик/Сарнахбюр, Ширакский',
    3742429 => 'Маралик, Ширакский',
    37424293 => 'Ширакскийаван, Ширакский',
    37424297 => 'Ани Каяран, Ширакский',
    37424300 => 'Ахурян/Арапи/Камо/Мусаелян, Ширакский',
    3742440 => 'Артик/Пемзашен, Ширакский',
    3742441 => 'Артик/Пемзашен, Ширакский',
    3742442 => 'Артик, Ширакский',
    3742443 => 'Артик, Ширакский',
    3742444 => 'Артик/Паник, Ширакский',
    3742445 => 'Артик, Ширакский',
    3742446 => 'Артик, Ширакский',
    3742447 => 'Артик/Пемзашен, Ширакский',
    3742448 => 'Артик/Пемзашен, Ширакский',
    37424481 => 'Артик/Паник, Ширакский',
    3742449 => 'Артик, Ширакский',
    37424492 => 'Паник, Ширакский',
    37424495 => 'Аревшат, Ширакский',
    37424496 => 'Мец Манташ, Ширакский',
    374245 => 'Ашоцк, Ширакский',
    374246 => 'Амасия, Ширакский',
    374249 => 'Талин, Арагацо́тн',
    3742494 => 'Талин/Арагац/Катнахбюр/Мастара, Арагацо́тн',
    37424973 => 'Катнахбюр, Арагацо́тн',
    37424981 => 'Талин/Арагац/Катнахбюр/Мастара, Арагацо́тн',
    3742499 => 'Арагацаван/Талин, Арагацо́тн',
    37424995 => 'Арагац, Арагацо́тн',
    37424997 => 'Мастара, Арагацо́тн',
    374252 => 'Апаран, Арагацо́тн',
    3742524 => 'Апаран/Артаван/Кучак, Арагацо́тн',
    37425281 => 'Апаран/Артаван/Кучак, Арагацо́тн',
    37425291 => 'Кучак, Арагацо́тн',
    37425295 => 'Артаван, Арагацо́тн',
    3742530 => 'Алаверди/Одзун/Цахкашат/Туманян, Лори',
    3742531 => 'Алаверди/Одзун/Цахкашат/Туманян, Лори',
    3742532 => 'Алаверди, Лори',
    3742533 => 'Алаверди, Лори',
    3742534 => 'Алаверди, Лори',
    3742535 => 'Алаверди, Лори',
    37425352 => 'Ахтала, Лори',
    37425353 => 'Шнох, Лори',
    37425356 => 'Чочкан, Лори',
    37425357 => 'Туманян, Лори',
    3742536 => 'Алаверди, Лори',
    3742537 => 'Алаверди/Ахтала/Туманян, Лори',
    3742538 => 'Алаверди/Одзун/Цахкашат/Туманян, Лори',
    37425381 => 'Алаверди/Ахтала/Туманян, Лори',
    3742539 => 'Алаверди/Одзун/Цахкашат/Туманян, Лори',
    374254 => 'Ташир, Лори',
    3742543 => 'Ташир/Мецаван, Лори',
    37425481 => 'Ташир/Мецаван, Лори',
    3742549 => 'Ташир/Мецаван, Лори',
    37425494 => 'Мецаван, Лори',
    374255 => 'Спитак, Лори',
    3742560 => 'Бовадзор/Степанаван, Лори',
    3742561 => 'Бовадзор/Степанаван, Лори',
    3742562 => 'Степанаван, Лори',
    3742563 => 'Степанаван, Лори',
    3742564 => 'Степанаван, Лори',
    3742565 => 'Бовадзор/Степанаван, Лори',
    3742566 => 'Степанаван, Лори',
    3742567 => 'Бовадзор/Степанаван, Лори',
    3742568 => 'Бовадзор/Степанаван, Лори',
    37425681 => 'Степанаван, Лори',
    3742569 => 'Степанаван, Лори',
    37425691 => 'Куртан, Лори',
    37425694 => 'Агарак, Лори',
    37425695 => 'Лежан, Лори',
    374257 => 'Арагац, Арагацо́тн',
    3742570 => 'Цахкаховит, Арагацо́тн',
    3742572 => 'Цахкаховит, Арагацо́тн',
    3742573 => 'Цахкаховит, Арагацо́тн',
    3742576 => 'Цахкаховит, Арагацо́тн',
    37425781 => 'Цахкаховит, Арагацо́тн',
    374261 => 'Севан, Гегаркуникский',
    374262 => 'Мартуни, Гегаркуникский',
    3742623 => 'Мартуни/Варденик, Гегаркуникский',
    37426252 => 'Варденик, Гегаркуникский',
    37426253 => 'Варденик, Гегаркуникский',
    37426272 => 'Личк, Гегаркуникский',
    37426281 => 'Мартуни/Варденик, Гегаркуникский',
    37426299 => 'Еранос, Гегаркуникский',
    3742630 => 'Азатамут/Гетаховит/Иджеван/Енокаван, Тавушский',
    3742631 => 'Азатамут/Гетаховит/Иджеван/Енокаван, Тавушский',
    3742632 => 'Иджеван/Айгеховит/Ачаджур, Тавушский',
    3742633 => 'Иджеван, Тавушский',
    3742634 => 'Иджеван, Тавушский',
    3742635 => 'Азатамут/Гетаховит/Иджеван/Енокаван, Тавушский',
    3742636 => 'Иджеван, Тавушский',
    3742637 => 'Иджеван, Тавушский',
    37426374 => 'Айгеховит, Тавушский',
    3742638 => 'Азатамут/Гетаховит/Иджеван/Енокаван, Тавушский',
    37426381 => 'Иджеван/Айгеховит/Ачаджур, Тавушский',
    3742639 => 'Иджеван, Тавушский',
    37426392 => 'Ачаджур, Тавушский',
    37426397 => 'Азатамут, Тавушский',
    374264 => 'Гавар, Гегаркуникский',
    3742640 => 'Гавар/Сарухан, Гегаркуникский',
    3742641 => 'Гавар/Сарухан, Гегаркуникский',
    3742647 => 'Гавар/Сарухан, Гегаркуникский',
    3742648 => 'Гавар/Сарухан, Гегаркуникский',
    374265 => 'Чамбарак, Гегаркуникский',
    3742654 => 'Чамбарак/Ваан, Гегаркуникский',
    37426581 => 'Чамбарак/Ваан, Гегаркуникский',
    37426596 => 'Ваан, Гегаркуникский',
    3742660 => 'Бердаван/Кохб/Ноемберян, Тавушский',
    3742661 => 'Бердаван/Кохб/Ноемберян, Тавушский',
    3742662 => 'Ноемберян, Тавушский',
    3742663 => 'Ноемберян/Воскепар/Кочи/Кохб, Тавушский',
    3742664 => 'Бердаван/Кохб/Ноемберян, Тавушский',
    3742665 => 'Кохб/Ноемберян, Тавушский',
    37426652 => 'Кохб, Тавушский',
    37426653 => 'Кохб, Тавушский',
    3742666 => 'Ноемберян, Тавушский',
    3742667 => 'Бердаван/Ноемберян, Тавушский',
    3742668 => 'Бердаван/Кохб/Ноемберян, Тавушский',
    37426681 => 'Ноемберян/Воскепар/Кочи/Кохб, Тавушский',
    37426690 => 'Ноемберян, Тавушский',
    37426691 => 'Ноемберян, Тавушский',
    37426692 => 'Арчис, Тавушский',
    37426693 => 'Баганис, Тавушский',
    37426694 => 'Ноемберян, Тавушский',
    37426695 => 'Зоракан, Тавушский',
    37426696 => 'Воскепар, Тавушский',
    37426697 => 'Ноемберян, Тавушский',
    37426698 => 'Ноемберян, Тавушский',
    37426699 => 'Кочи, Тавушский',
    3742670 => 'Айгепар/Берд, Тавушский',
    3742671 => 'Айгепар/Берд, Тавушский',
    3742672 => 'Берд, Тавушский',
    3742673 => 'Берд/Мосесгех/Навур/Норашен, Тавушский',
    3742674 => 'Айгепар/Берд, Тавушский',
    3742675 => 'Арцваберд/Берд, Тавушский',
    3742676 => 'Берд, Тавушский',
    3742677 => 'Берд, Тавушский',
    3742678 => 'Айгепар/Берд, Тавушский',
    37426781 => 'Берд/Мосесгех/Навур/Норашен, Тавушский',
    3742679 => 'Берд, Тавушский',
    37426791 => 'Навур, Тавушский',
    37426794 => 'Товуз, Тавушский',
    37426796 => 'Мосесгех, Тавушский',
    37426797 => 'Норашен, Тавушский',
    3742680 => 'Дилижан, Тавушский',
    3742682 => 'Дилижан, Тавушский',
    3742683 => 'Дилижан, Тавушский',
    3742684 => 'Дилижан/Агарцин/Техут, Тавушский',
    3742686 => 'Дилижан, Тавушский',
    37426881 => 'Дилижан/Агарцин/Техут, Тавушский',
    3742689 => 'Дилижан, Тавушский',
    37426895 => 'Агарцин, Тавушский',
    37426897 => 'Техут, Тавушский',
    374269 => 'Варденис, Гегаркуникский',
    3742810 => 'Гетап/Салли/Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    3742811 => 'Гетап/Салли/Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    3742812 => 'Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    3742813 => 'Ехегнадзор/Малишка/Шатин, ВАЙОЦДЗОРСКИЙ',
    3742814 => 'Гетап/Салли/Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    3742815 => 'Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    37428151 => 'Хачик, ВАЙОЦДЗОРСКИЙ',
    3742816 => 'Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    3742817 => 'Гетап/Салли/Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    3742818 => 'Гетап/Салли/Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    37428181 => 'Ехегнадзор/Малишка/Шатин, ВАЙОЦДЗОРСКИЙ',
    37428190 => 'Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    37428191 => 'Арпи, ВАЙОЦДЗОРСКИЙ',
    37428192 => 'Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    37428193 => 'Агавнадзор, ВАЙОЦДЗОРСКИЙ',
    37428194 => 'Арени, ВАЙОЦДЗОРСКИЙ',
    37428195 => 'Малишка, ВАЙОЦДЗОРСКИЙ',
    37428196 => 'Ехегнадзор, ВАЙОЦДЗОРСКИЙ',
    37428197 => 'Елпин, ВАЙОЦДЗОРСКИЙ',
    37428198 => 'Ринд, ВАЙОЦДЗОРСКИЙ',
    37428199 => 'Шатин, ВАЙОЦДЗОРСКИЙ',
    374282 => 'Вайк, ВАЙОЦДЗОРСКИЙ',
    3742830 => 'Сисиан, Сюника',
    3742832 => 'Сисиан, Сюника',
    3742833 => 'Сисиан, Сюника',
    37428351 => 'Сисиан, Сюника',
    3742836 => 'Сисиан, Сюника',
    3742837 => 'Сисиан, Сюника',
    37428375 => 'Тасик, Сюника',
    3742838 => 'Сисиан, Сюника',
    3742839 => 'Сисиан, Сюника',
    37428396 => 'Ангехакот, Сюника',
    374284 => 'Горис, Сюника',
    3742840 => 'Горис/Веришен, Сюника',
    3742841 => 'Горис/Веришен, Сюника',
    37428427 => 'Веришен, Сюника',
    3742847 => 'Горис/Веришен, Сюника',
    3742848 => 'Горис/Веришен, Сюника',
    37428491 => 'Аржис, Сюника',
    37428494 => 'Хндзореск, Сюника',
    37428495 => 'Шинуайр, Сюника',
    37428499 => 'Корнидзор, Сюника',
    3742850 => 'Давит Бек/Каджаран/Капан, Сюника',
    3742851 => 'Давит Бек/Каджаран/Капан, Сюника',
    3742852 => 'Капан, Сюника',
    3742853 => 'Каджаран, Сюника',
    37428540 => 'Капан, Сюника',
    37428541 => 'Капан, Сюника',
    37428542 => 'Капан, Сюника',
    37428543 => 'Капан, Сюника',
    37428544 => 'Капан, Сюника',
    37428545 => 'Каджаран, Сюника',
    37428546 => 'Каджаран, Сюника',
    37428547 => 'Каджаран, Сюника',
    37428548 => 'Каджаран, Сюника',
    37428549 => 'Каджаран, Сюника',
    3742855 => 'Капан, Сюника',
    3742856 => 'Капан, Сюника',
    3742857 => 'Давит Бек/Каджаран/Капан, Сюника',
    3742858 => 'Давит Бек/Каджаран/Капан, Сюника',
    374285810 => 'Капан, Сюника',
    374285811 => 'Капан, Сюника',
    374285812 => 'Капан, Сюника',
    374285813 => 'Капан, Сюника',
    374285814 => 'Капан, Сюника',
    374285815 => 'Каджаран, Сюника',
    374285816 => 'Каджаран, Сюника',
    374285817 => 'Каджаран, Сюника',
    374285818 => 'Каджаран, Сюника',
    374285819 => 'Каджаран, Сюника',
    3742859 => 'Капан, Сюника',
    3742860 => 'Мегри/Агарак, Сюника',
    3742861 => 'Мегри/Агарак, Сюника',
    3742862 => 'Агарак, Сюника',
    3742863 => 'Мегри, Сюника',
    3742864 => 'Мегри, Сюника',
    3742865 => 'Агарак/Шванидзор, Сюника',
    3742866 => 'Мегри, Сюника',
    3742867 => 'Мегри/Агарак, Сюника',
    3742868 => 'Мегри/Агарак, Сюника',
    374286810 => 'Мегри, Сюника',
    374286811 => 'Мегри, Сюника',
    374286812 => 'Мегри, Сюника',
    374286813 => 'Мегри, Сюника',
    374286814 => 'Мегри, Сюника',
    374286815 => 'Агарак/Мегри, Сюника',
    374286816 => 'Агарак/Мегри, Сюника',
    374286817 => 'Агарак/Мегри, Сюника',
    374286818 => 'Агарак/Мегри, Сюника',
    374286819 => 'Агарак/Мегри, Сюника',
    3742869 => 'Мегри, Сюника',
    37428695 => 'Шванидзор, Сюника',
    374287 => 'Джермук, ВАЙОЦДЗОРСКИЙ',
    3742873 => 'Джермук/Гндеваз, ВАЙОЦДЗОРСКИЙ',
    37428781 => 'Джермук/Гндеваз, ВАЙОЦДЗОРСКИЙ',
    37428794 => 'Гндеваз, ВАЙОЦДЗОРСКИЙ',
    374312 => 'Гюмри, Ширакский',
    3743120 => 'Гюмри/Ахурян, Ширакский',
    3743121 => 'Гюмри/Ахурян, Ширакский',
    3743127 => 'Ахурян, Ширакский',
    37431280 => 'Ахурян, Ширакский',
    37431281 => 'Ахурян, Ширакский',
    37431282 => 'Ахурян, Ширакский',
    37431283 => 'Ахурян, Ширакский',
    37431284 => 'Ахурян, Ширакский',
    374312859 => 'Ахурян, Ширакский',
    37431286 => 'Гюмри/Ахурян, Ширакский',
    37431287 => 'Гюмри/Ахурян, Ширакский',
    37431288 => 'Гюмри/Ахурян, Ширакский',
    37431289 => 'Гюмри/Ахурян, Ширакский',
    374322 => 'Ванадзор, Лори',
    3743220 => 'Ванадзор/Гугарк, Лори',
    3743221 => 'Ванадзор/Гугарк, Лори',
    3743228 => 'Ванадзор/Гугарк, Лори',
    37432293 => 'Памбак, Лори',
    37432294 => 'Лернапат, Лори',
    37432295 => 'Ехегнут, Лори',
    37432296 => 'Маргаовит, Лори',
    37432297 => 'Дзорагет, Лори',
    37432298 => 'Лермонтово, Лори',
    37432299 => 'Ваагни, Лори',
    374470 => 'Нагорный Карабах',
    374471 => 'Степанакерт',
    374472 => 'Нагорный Карабах',
    374473 => 'Нагорный Карабах',
    374474 => 'Мартакерт',
    374475 => 'Гадрут',
    374476 => 'Аскеран',
    374477 => 'Шуши',
    37447732 => 'Бердзор/Кашатах',
    374478 => 'Мартуни',
    374479 => 'Степанакерт',
];
