<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    3210 => 'Wavre',
    3211 => 'Hasselt',
    3212 => 'Tongeren',
    3213 => 'Diest',
    3214 => 'Herentals',
    3215 => 'Mechelen',
    3216 => 'Leuven',
    3219 => 'Waremme',
    322 => 'Brussels',
    323 => 'Antwerp',
    3242 => 'Liège',
    3243 => 'Liège',
    3250 => 'Bruges',
    3251 => 'Roeselare',
    3252 => 'Dendermonde',
    3253 => 'Aalst',
    3254 => 'Ninove',
    3255 => 'Ronse',
    3256 => 'Kortrijk',
    3257 => 'Ypres',
    3258 => 'Veurne',
    3259 => 'Ostend',
    3260 => 'Chimay',
    3261 => 'Libramont-Chevigny',
    3263 => 'Arlon',
    3264 => 'La Louvière',
    3265 => 'Mons',
    3267 => 'Nivelles',
    3268 => 'Ath',
    3269 => 'Tournai',
    3271 => 'Charleroi',
    3280 => 'Stavelot',
    3281 => 'Namur',
    3282 => 'Dinant',
    3283 => 'Ciney',
    3284 => 'Marche-en-Famenne',
    3285 => 'Huy',
    3286 => 'Durbuy',
    3287 => 'Verviers',
    3289 => 'Genk',
    329 => 'Ghent',
];
