<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    3822 => 'Danilovgad/Kolasin/Podgorica',
    38230 => 'Bar/Ulcinj',
    38231 => 'Herceg Novi',
    38232 => 'Kotor/Tivat',
    38233 => 'Budva',
    38240 => 'Niksic/Pluzine/Savnik',
    38241 => 'Cetinje',
    38250 => 'Bijelo Polje/Mojkovac',
    38251 => 'Andrijevica/Berane/Blue/Gusinje/Petnitsa/Rožaje',
    38252 => 'Pljevlja/Zabljak',
];
