<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    96350 => 'Rcell',
    96391 => 'Wafa Telecom',
    96392 => 'Wafa Telecom',
    96393 => 'Syriatel',
    96394 => 'MTN',
    963950 => 'MTN',
    963952 => 'MTN',
    963954 => 'MTN',
    963955 => 'MTN',
    963956 => 'MTN',
    963957 => 'MTN',
    963958 => 'MTN',
    963959 => 'MTN',
    96396 => 'MTN',
    96398 => 'Syriatel',
    96399 => 'Syriatel',
];
