<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    3751511 => 'Вялікая Бераставіца, Гродзенская вобласць',
    3751512 => 'Ваўкавыск',
    3751513 => 'Свіслач, Гродзенская вобласць',
    3751514 => 'Шчучын, Гродзенская вобласць',
    3751515 => 'Масты, Гродзенская вобласць',
    375152 => 'Гродна',
    375154 => 'Ліда',
    3751562 => 'Слонім',
    3751563 => 'Дзятлава, Гродзенская вобласць',
    3751564 => 'Зэльва, Гродзенская вобласць',
    3751591 => 'Астравец, Гродзенская вобласць',
    3751592 => 'Смаргонь',
    3751593 => 'Ашмяны',
    3751594 => 'Воранава, Гродзенская вобласць',
    3751595 => 'Іўе, Гродзенская вобласць',
    3751596 => 'Карэлічы, Гродзенская вобласць',
    3751597 => 'Навагрудак',
    375162 => 'Брэст',
    375163 => 'Баранавічы',
    3751631 => 'Камянец, Брэсцкая вобласць',
    3751632 => 'Пружаны, Брэсцкая вобласць',
    3751633 => 'Ляхавічы, Брэсцкая вобласць',
    3751641 => 'Жабінка, Брэсцкая вобласць',
    3751642 => 'Кобрын',
    3751643 => 'Бяроза, Брэсцкая вобласць',
    3751644 => 'Драгічын, Брэсцкая вобласць',
    3751645 => 'Івацэвічы, Брэсцкая вобласць',
    3751646 => 'Ганцавічы, Брэсцкая вобласць',
    3751647 => 'Лунінец, Брэсцкая вобласць',
    375165 => 'Пінск',
    3751651 => 'Маларыта, Брэсцкая вобласць',
    3751652 => 'Іванава, Брэсцкая вобласць',
    3751655 => 'Столін, Брэсцкая вобласць',
    37517 => 'Мінск',
    3751713 => 'Мар’іна Горка, Мінская вобласць',
    3751714 => 'Чэрвень',
    3751715 => 'Беразіно, Мінская вобласць',
    3751716 => 'Дзяржынск',
    3751717 => 'Стаўбцы',
    3751718 => 'Узда, Мінская вобласць',
    3751719 => 'Капыль, Мінская вобласць',
    375174 => 'Салігорск',
    375176 => 'Маладзечна',
    375177 => 'Барысаў',
    3751770 => 'Нясвіж',
    3751771 => 'Вілейка',
    3751772 => 'Валожын',
    3751774 => 'Лагойск',
    3751775 => 'Жодзіна',
    3751776 => 'Смалявічы',
    3751792 => 'Старыя Дарогі, Мінская вобласць',
    3751793 => 'Клецк, Мінская вобласць',
    3751794 => 'Любань, Мінская вобласць',
    3751795 => 'Слуцк',
    3751796 => 'Крупкі, Мінская вобласць',
    3751797 => 'Мядзел',
    375212 => 'Віцебск',
    3752130 => 'Шуміліна, Віцебская вобласць',
    3752131 => 'Бешанковічы, Віцебская вобласць',
    3752132 => 'Лепель',
    3752133 => 'Чашнікі, Віцебская вобласць',
    3752135 => 'Сянно, Віцебская вобласць',
    3752136 => 'Талачын',
    3752137 => 'Дуброўна, Віцебская вобласць',
    3752138 => 'Лёзна, Віцебская вобласць',
    3752139 => 'Гарадок, Віцебская вобласць',
    375214 => 'Полацк/Наваполацк',
    3752151 => 'Верхнядзвінск, Віцебская вобласць',
    3752152 => 'Міёры, Віцебская вобласць',
    3752153 => 'Браслаў',
    3752154 => 'Шаркоўшчына, Віцебская вобласць',
    3752155 => 'Паставы',
    3752156 => 'Глыбокае',
    3752157 => 'Докшыцы, Віцебская вобласць',
    3752158 => 'Ушачы, Віцебская вобласць',
    3752159 => 'Расоны, Віцебская вобласць',
    375216 => 'Орша',
    375222 => 'Магілёў',
    3752230 => 'Глуск, Магілёўская вобласць',
    3752231 => 'Быхаў, Магілёўская вобласць',
    3752232 => 'Бялынічы, Магілёўская вобласць',
    3752233 => 'Горкі, Магілёўская вобласць',
    3752234 => 'Круглае, Магілёўская вобласць',
    3752235 => 'Асіповічы',
    3752236 => 'Клічаў, Магілёўская вобласць',
    3752237 => 'Кіраўск, Магілёўская вобласць',
    3752238 => 'Краснаполле, Магілёўская вобласць',
    3752239 => 'Шклоў',
    3752240 => 'Мсціслаў',
    3752241 => 'Крычаў, Магілёўская вобласць',
    3752242 => 'Чавусы, Магілёўская вобласць',
    3752243 => 'Чэрыкаў, Магілёўская вобласць',
    3752244 => 'Клімавічы, Магілёўская вобласць',
    3752245 => 'Касцюковічы, Магілёўская вобласць',
    3752246 => 'Слаўгарад, Магілёўская вобласць',
    3752247 => 'Хоцімск, Магілёўская вобласць',
    3752248 => 'Дрыбін, Магілёўская вобласць',
    375225 => 'Бабруйск',
    375232 => 'Гомель',
    3752330 => 'Ветка, Гомельская вобласць',
    3752332 => 'Чачэрск, Гомельская вобласць',
    3752333 => 'Добруш, Гомельская вобласць',
    3752334 => 'Жлобін',
    3752336 => 'Буда-Кашалёва, Гомельская вобласць',
    3752337 => 'Карма, Гомельская вобласць',
    3752339 => 'Рагачоў',
    3752340 => 'Рэчыца',
    3752342 => 'Светлагорск',
    3752344 => 'Брагін, Гомельская вобласць',
    3752345 => 'Калінкавічы',
    3752346 => 'Хойнікі, Гомельская вобласць',
    3752347 => 'Лоеў, Гомельская вобласць',
    3752350 => 'Петрыкаў, Гомельская вобласць',
    3752353 => 'Жыткавічы, Гомельская вобласць',
    3752354 => 'Ельск, Гомельская вобласць',
    3752355 => 'Нароўля, Гомельская вобласць',
    3752356 => 'Лельчыцы, Гомельская вобласць',
    3752357 => 'Акцябрскі, Гомельская вобласць',
    375236 => 'Мазыр',
];
