<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    3212 => 'Tongern',
    3215 => 'Mecheln',
    3216 => 'Löwen',
    322 => 'Brüssel',
    323 => 'Antwerpen',
    3242 => 'Lüttich',
    3243 => 'Lüttich',
    3250 => 'Brügge',
    3257 => 'Ypern',
    3259 => 'Ostende',
    3263 => 'Arel',
    3265 => 'Bergen',
    3280 => 'Stablo',
    3281 => 'Namür',
    329 => 'Gent',
];
