<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    223202 => 'Bamako',
    2232070 => 'Bamako',
    2232071 => 'Bamako',
    2232072 => 'Bamako',
    2232073 => 'Bamako',
    2232074 => 'Bamako',
    2232075 => 'Bamako',
    2232076 => 'Bamako',
    2232077 => 'Bamako',
    2232078 => 'Bamako',
    223212 => 'Koulikoro',
    223214 => 'Mopti',
    223215 => 'Kayes',
    223216 => 'Sikasso',
    223218 => 'Gao/Kidal',
    223219 => 'Tombouctou',
    223442 => 'Bamako',
    223443 => 'Bamako',
    223449 => 'Bamako',
];
