<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    2410140 => 'Kango',
    24101420 => 'Ntoum',
    24101424 => 'Cocobeach',
    2410144 => 'Libreville',
    2410145 => 'Libreville',
    2410146 => 'Libreville',
    2410147 => 'Libreville',
    2410148 => 'Libreville',
    2410150 => 'Gamba',
    2410154 => 'Omboué',
    2410155 => 'Port-Gentil',
    2410156 => 'Port-Gentil',
    2410158 => 'Lambaréné',
    2410159 => 'Ndjolé',
    2410160 => 'Ngouoni',
    2410162 => 'Mounana',
    2410164 => 'Lastoursville',
    2410165 => 'Koulamoutou',
    2410166 => 'Moanda',
    2410167 => 'Franceville',
    2410169 => 'Léconi/Akiéni/Okondja',
    241017 => 'Libreville',
    2410182 => 'Tchibanga',
    2410183 => 'Mayumba',
    2410186 => 'Mouila',
    2410190 => 'Makokou',
    2410192 => 'Mékambo',
    2410193 => 'Booué',
    2410196 => 'Bitam',
    2410198 => 'Oyem',
    2411140 => 'Kango',
    24111420 => 'Ntoum',
    24111424 => 'Cocobeach',
    2411144 => 'Libreville',
    2411145 => 'Libreville',
    2411146 => 'Libreville',
    2411147 => 'Libreville',
    2411148 => 'Libreville',
    2411150 => 'Gamba',
    2411154 => 'Omboué',
    2411155 => 'Port-Gentil',
    2411156 => 'Port-Gentil',
    2411158 => 'Lambaréné',
    2411159 => 'Ndjolé',
    2411160 => 'Ngouoni',
    2411162 => 'Mounana',
    2411164 => 'Lastoursville',
    2411165 => 'Koulamoutou',
    2411166 => 'Moanda',
    2411167 => 'Franceville',
    2411169 => 'Léconi/Akiéni/Okondja',
    241117 => 'Libreville',
    2411182 => 'Tchibanga',
    2411183 => 'Mayumba',
    2411186 => 'Mouila',
    2411190 => 'Makokou',
    2411192 => 'Mékambo',
    2411193 => 'Booué',
    2411196 => 'Bitam',
    2411198 => 'Oyem',
];
