<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    4122 => 'Genf',
    4126 => 'Freiburg',
    4127 => 'Sitten',
    4131 => 'Bern',
    4132 => 'Biel/Neuenburg/Solothurn/Jura',
    4141 => 'Luzern',
    4143 => 'Zürich',
    4144 => 'Zürich',
];
