<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AC' => 'Aßension',
    'AD' => 'Andorra',
    'AE' => 'Vereinschte Arrabesche Emmirate',
    'AF' => 'Afjaanistahn',
    'AG' => 'Antigwa un Barbuda',
    'AI' => 'Anggwilla',
    'AL' => 'Albaanije',
    'AM' => 'Arrmeenije',
    'AO' => 'Angjoola',
    'AQ' => 'der Södpol',
    'AR' => 'Ajjentiinije',
    'AS' => 'Ammerikaanesch Sammoha',
    'AT' => 'Öösterisch',
    'AU' => 'Austraalije',
    'AW' => 'Aruba',
    'AX' => 'de Ohland-Enselle',
    'AZ' => 'Asserbaidschahn',
    'BA' => 'Boßnije un Herzegovina',
    'BB' => 'de Ensel Barbados',
    'BD' => 'Bangladesch',
    'BE' => 'Bellje',
    'BF' => 'Bukkinna-Faase',
    'BG' => 'Bulljaarije',
    'BH' => 'Bachrain',
    'BI' => 'Burundi',
    'BJ' => 'dä Benin',
    'BL' => 'de Zint Battälmi-Enselle',
    'BM' => 'de Bermudas',
    'BN' => 'Brunei',
    'BO' => 'Bolliivije',
    'BQ' => 'de karribbesche Nederläng',
    'BR' => 'Brasilije',
    'BS' => 'de Bahamas',
    'BT' => 'Buttaan',
    'BW' => 'Bozwaana',
    'BY' => 'Wießrußland',
    'BZ' => 'Belize',
    'CA' => 'Kanada',
    'CC' => 'de Kokkos-Enselle',
    'CD' => 'dä Konggo (Kinschasa)',
    'CF' => 'de Zäntraalaffrikaanesche Republik',
    'CG' => 'dä Konggo (Brassavill)',
    'CH' => 'de Schweiz',
    'CI' => 'Älfebeijn-Köß',
    'CK' => 'de Kuuk-Enselle',
    'CL' => 'Schiile',
    'CM' => 'Kammeruhn',
    'CN' => 'Schiina',
    'CO' => 'Kolumbije',
    'CR' => 'Kostarika',
    'CU' => 'Kuhba',
    'CV' => 'de kapvärdesche Enselle',
    'CW' => 'Curaçao',
    'CX' => 'de Weihnaachs-Ensel',
    'CY' => 'Züppere',
    'CZ' => 'de Tschäschei',
    'DE' => 'Doütschland',
    'DG' => 'de Diego-Garcia-Ensel',
    'DJ' => 'Dschibutti',
    'DK' => 'Dänemark',
    'DM' => 'Dominnika',
    'DO' => 'de Dommenekaanesche Reppublik',
    'DZ' => 'Alljeerije',
    'EA' => 'Ze’uta un Meliija',
    'EC' => 'Äkwador',
    'EE' => 'Äßland',
    'EG' => 'Äjüpte',
    'EH' => 'Wäß-Sahara',
    'ER' => 'Äritreja',
    'ES' => 'Schpaanije',
    'ET' => 'Ättijoopije',
    'FI' => 'Finnland',
    'FJ' => 'de Fidschi-Endelle',
    'FK' => 'de Falkland-Enselle',
    'FM' => 'Mikroneesije',
    'FO' => 'de Färrör-Enselle',
    'FR' => 'Frankrisch',
    'GA' => 'Jabuhn',
    'GB' => 'Jruußbrettannije',
    'GD' => 'Jrenahda',
    'GE' => 'Jeorrjije',
    'GF' => 'Franzüüsesch Jujaana',
    'GG' => 'Jöönsei',
    'GH' => 'Jaana',
    'GI' => 'Jibralltaa',
    'GL' => 'Jröhnland',
    'GM' => 'Jambija',
    'GN' => 'Jinneha',
    'GP' => 'Juadelupp',
    'GQ' => 'Äquatorial Jineeja',
    'GR' => 'Jriescheland',
    'GS' => 'Söd-Jeorjie un de södlijje Botteramms-Enselle',
    'GT' => 'Juwatemahla',
    'GU' => 'Juham',
    'GW' => 'Jinneha_Bißau',
    'GY' => 'Jujaana',
    'HK' => 'Hongkong',
    'HN' => 'Honduras',
    'HR' => 'Krowazije',
    'HT' => 'Ha’itti',
    'HU' => 'Unjann',
    'IC' => 'de Kannaresche Enselle',
    'ID' => 'Indoneesije',
    'IE' => 'Irrland',
    'IL' => 'Ißraäl',
    'IM' => 'de Ensel Män',
    'IN' => 'Indije',
    'IQ' => 'Irak',
    'IR' => 'Persije',
    'IS' => 'Ißland',
    'IT' => 'Itaalije',
    'JE' => 'Jööseh',
    'JM' => 'Jammaika',
    'JO' => 'Jordaanije',
    'JP' => 'Japan',
    'KE' => 'Keenija',
    'KG' => 'Kirrjiisije',
    'KH' => 'Kambodscha',
    'KI' => 'Kiribati',
    'KM' => 'de Kommoore',
    'KN' => 'Zint Kitts un Nevis',
    'KP' => 'Nood-Koreja',
    'KR' => 'Söd-Koreja',
    'KW' => 'Kuweit',
    'KY' => 'de Kaiman-Enselle',
    'KZ' => 'Kassakstahn',
    'LA' => 'La’os',
    'LB' => 'Lebbannon',
    'LC' => 'de Ensel Zint-Lutscha',
    'LI' => 'Lischteschtein',
    'LK' => 'Sri Lanka',
    'LR' => 'Libeerija',
    'LS' => 'Lesooto',
    'LT' => 'Littaue',
    'LU' => 'Luxembursch',
    'LV' => 'Lätland',
    'LY' => 'Libbije',
    'MA' => 'Marokko',
    'MC' => 'Monakko',
    'MD' => 'Moldaavije',
    'ME' => 'et Monteneejro',
    'MF' => 'de Zint-Määtes-Ensel',
    'MG' => 'Maddajaska',
    'MH' => 'de Machschall-Enselle',
    'ML' => 'Maali',
    'MM' => 'Birma',
    'MN' => 'Mongjolei',
    'MO' => 'Makau',
    'MP' => 'de nöödlijje Marijanne-Enselle',
    'MQ' => 'Machtinik',
    'MR' => 'Mautitaanije',
    'MS' => 'Mongßerrat',
    'MT' => 'Malta',
    'MU' => 'Maurizijus',
    'MV' => 'Mallediive',
    'MW' => 'Malawi',
    'MX' => 'Mäxiko',
    'MY' => 'Malaisije',
    'MZ' => 'Mosambik',
    'NA' => 'Namiibije',
    'NC' => 'Neuschottland',
    'NE' => 'Nijer',
    'NF' => 'de Noofok-Ensel',
    'NG' => 'Nikaraagua',
    'NI' => 'Nikarahguwa',
    'NL' => 'de Nederläng',
    'NO' => 'Norrweeje',
    'NP' => 'Nepall',
    'NR' => 'Nauru',
    'NU' => 'Niue',
    'NZ' => 'Neuseeland',
    'OM' => 'Oman',
    'PA' => 'Pannama',
    'PE' => 'Perruh',
    'PF' => 'Franzüüsesch Pollineesije',
    'PG' => 'Papuwa Neujineeja',
    'PH' => 'Fillipiine',
    'PK' => 'Pakistahn',
    'PL' => 'Pole',
    'PM' => 'Zint Pjäär un Mikelong',
    'PN' => 'de Pitkärn-Ensel',
    'PR' => 'Pochtoriko',
    'PS' => 'Palästina',
    'PT' => 'Pochtojall',
    'PW' => 'Pallau',
    'PY' => 'Parraguwai',
    'QA' => 'Kataa',
    'RE' => 'Rehunjohn',
    'RO' => 'Romäänije',
    'RS' => 'Särbije',
    'RU' => 'Rußland',
    'RW' => 'Ruanda',
    'SA' => 'Saudi Arraabije',
    'SB' => 'de Solomone-Enselle',
    'SC' => 'de Seischälle',
    'SD' => 'Noodsudahn',
    'SE' => 'Schweede',
    'SG' => 'Singjapuur',
    'SH' => 'de Ensel Zint Hellena',
    'SI' => 'ẞloveenije',
    'SJ' => 'de Enselle Svalbard un Jan Mayen',
    'SK' => 'ẞlovakei',
    'SL' => 'Sjärra Lejone',
    'SM' => 'San-Marino',
    'SN' => 'der Sennejall',
    'SO' => 'Somaalije',
    'SR' => 'Sürinamm',
    'SS' => 'Södsudahn',
    'ST' => 'Zint Tommeh un Printschipe',
    'SV' => 'Äl Slavadohr',
    'SX' => 'Zint Maarten',
    'SY' => 'Sürije',
    'SZ' => 'ẞwaasiland',
    'TA' => 'Tristan da Cunja',
    'TC' => 'de Enselle Turks un Kaikos',
    'TD' => 'der Tschadd',
    'TF' => 'Franzüüsesche Södsee-Enselle',
    'TG' => 'Toojo',
    'TH' => 'Tailand',
    'TJ' => 'Tadschikistahn',
    'TK' => 'Tokelau',
    'TL' => 'Oß-Timor',
    'TM' => 'Turkmenistahn',
    'TN' => 'Tuneesije',
    'TO' => 'Tongga',
    'TR' => 'de Törkei',
    'TT' => 'Trinidad un Tobähjo',
    'TV' => 'Tuvalu',
    'TW' => 'Taiwan',
    'TZ' => 'Tansanija',
    'UA' => 'de Ukra’iine',
    'UG' => 'Ujanda',
    'UM' => 'de Vereineschte Schtaate vun Amärrika ier ußerhallef jelääje Enselsche',
    'US' => 'de vereineschte Schtaate vun Ammärrika',
    'UY' => 'Urrujwai',
    'UZ' => 'Ußbeekistahn',
    'VA' => 'der Vattikahn',
    'VC' => 'Zint Vinzänz un de Jrenadines-Enselle',
    'VE' => 'Venezuela',
    'VG' => 'de brettesche Juffer-Enselle',
    'VI' => 'de ammärrikahnesche Juffer-Enselle',
    'VN' => 'Vijätnamm',
    'VU' => 'Vanuatu',
    'WF' => 'Wallis un Futuna',
    'WS' => 'Sammoha',
    'XK' => 'Kosovo',
    'YE' => 'Jämme',
    'YT' => 'Majott',
    'ZA' => 'de Republik Södaffrika',
    'ZM' => 'Sambija',
    'ZW' => 'Simbabwe',
];
