<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    96770 => 'Y',
    96771 => 'SabaFon',
    96773 => 'MTN',
    96777 => 'Yemen Mobile',
    96778 => 'Yemen Mobile',
];
