<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    25641 => 'Kampala',
    25643 => 'Jinja',
    25645 => 'Mbale',
    25646 => 'Mityana',
    256464 => 'Mubende',
    256465 => 'Masindi',
    256471 => 'Gulu',
    256473 => 'Lira',
    256476 => 'Arua',
    256481 => 'Masaka',
    256483 => 'Fort Portal',
    256485 => 'Mbarara',
    256486 => 'Kabale/Rukungiri/Kisoro',
];
