<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    336000 => 'Free Mobile',
    336001 => 'Orange France',
    336002 => 'SFR',
    336003 => 'Bouygues',
    3360040 => 'Zeop',
    3360041 => 'Orange France',
    3360042 => 'Digicel Antilles Francaises Guyane',
    3360043 => 'Dauphin Telecom',
    3360044 => 'OUTREMER TELECOM',
    3360045 => 'UTS CARAIBES',
    3360051 => 'Orange France',
    3360052 => 'SFR',
    3360053 => 'BJT',
    3360054 => 'Only (Telco OI)',
    3360055 => 'Only (Telco OI)',
    336006 => 'Free Mobile',
    336007 => 'SFR',
    336008 => 'Orange France',
    336009 => 'Bouygues',
    33601 => 'SFR',
    33602 => 'SFR',
    33603 => 'SFR',
    336040 => 'Afone',
    336041 => 'Afone',
    336042 => 'e*Message',
    336043 => 'e*Message',
    336044 => 'Afone',
    336045 => 'SFR',
    336046 => 'SFR',
    336047 => 'SFR',
    336048 => 'SFR',
    336049 => 'SFR',
    336050 => 'Euroinformation Telecom',
    336051 => 'Euroinformation Telecom',
    336052 => 'Euroinformation Telecom',
    336053 => 'Euroinformation Telecom',
    336054 => 'Euroinformation Telecom',
    336055 => 'Lycamobile',
    336056 => 'Lycamobile',
    336057 => 'Lycamobile',
    336058 => 'Lycamobile',
    336059 => 'Lycamobile',
    336060 => 'e*Message',
    336061 => 'e*Message',
    336062 => 'e*Message',
    336063 => 'e*Message',
    336064 => 'Afone',
    336065 => 'Euroinformation Telecom',
    336066 => 'Euroinformation Telecom',
    336067 => 'Euroinformation Telecom',
    336068 => 'Euroinformation Telecom',
    336069 => 'Euroinformation Telecom',
    33607 => 'Orange France',
    33608 => 'Orange France',
    33609 => 'SFR',
    3361 => 'SFR',
    3362 => 'SFR',
    3363 => 'Orange France',
    33634 => 'SFR',
    33635 => 'SFR',
    33636 => 'Euroinformation Telecom',
    3363800 => 'Globalstar Europe',
    3363801 => 'Prixtel',
    3363802 => 'Prixtel',
    3363803 => 'Prixtel',
    3363804 => 'Prixtel',
    3363805 => 'Prixtel',
    3363806 => 'IP Directions',
    3363807 => 'Alphalink',
    3363808 => 'Alphalink',
    3363809 => 'Alphalink',
    33640 => 'Orange France',
    3364000 => 'Globalstar Europe',
    3364001 => 'Globalstar Europe',
    3364002 => 'Globalstar Europe',
    3364003 => 'Globalstar Europe',
    3364004 => 'Globalstar Europe',
    3364005 => 'Coriolis Telecom',
    3364006 => 'Coriolis Telecom',
    3364007 => 'Coriolis Telecom',
    3364008 => 'Coriolis Telecom',
    3364009 => 'Coriolis Telecom',
    336410 => 'La poste telecom',
    336411 => 'La poste telecom',
    336412 => 'La poste telecom',
    336413 => 'La poste telecom',
    336414 => 'La poste telecom',
    336415 => 'La poste telecom',
    3364160 => 'Euroinformation Telecom',
    3364161 => 'Euroinformation Telecom',
    3364162 => 'Mobiquithings',
    3364163 => 'SCT',
    3364164 => 'Legos',
    3364165 => 'e*Message',
    3364166 => 'SFR',
    3364167 => 'SFR',
    3364168 => 'SFR',
    3364169 => 'SFR',
    33642 => 'Orange France',
    33643 => 'Orange France',
    336440 => 'La poste telecom',
    336441 => 'Orange France',
    336442 => 'Orange France',
    336443 => 'Orange France',
    336444 => 'Transatel',
    336445 => 'Transatel',
    336446 => 'Transatel',
    336447 => 'La poste telecom',
    336448 => 'La poste telecom',
    336449 => 'La poste telecom',
    33645 => 'Orange France',
    33646 => 'SFR',
    33647 => 'Orange France',
    33648 => 'Orange France',
    33649 => 'Orange France',
    3364950 => 'Keyyo',
    3364990 => 'Intercall',
    3364991 => 'Intercall',
    3364994 => 'e*Message',
    3364995 => 'Prixtel',
    3364996 => 'e*Message',
    3364997 => 'e*Message',
    3364998 => 'Prixtel',
    3364999 => 'SFR',
    33650 => 'Bouygues',
    33651 => 'Free Mobile',
    33652 => 'Free Mobile',
    336530 => 'Bouygues',
    336531 => 'Bouygues',
    336532 => 'Bouygues',
    336533 => 'Bouygues',
    336534 => 'Bouygues',
    336535 => 'Free Mobile',
    336536 => 'Free Mobile',
    336537 => 'Free Mobile',
    336538 => 'Free Mobile',
    336539 => 'Free Mobile',
    33654 => 'Orange France',
    33655 => 'SFR',
    33656 => 'e*Message',
    3365660 => 'Mobiquithings',
    3365661 => 'Airbus Defence and Space',
    3365662 => 'Mobiquithings',
    3365663 => 'Mobiquithings',
    3365664 => 'Mobiquithings',
    3365665 => 'Mobiquithings',
    3365666 => 'Prixtel',
    3365667 => 'Prixtel',
    3365668 => 'Prixtel',
    3365669 => 'Prixtel',
    336567 => 'La poste telecom',
    336568 => 'La poste telecom',
    33657 => 'e*Message',
    33658 => 'Bouygues',
    33659 => 'Bouygues',
    3366 => 'Bouygues',
    3367 => 'Orange France',
    3368 => 'Orange France',
    33695 => 'Free Mobile',
    33698 => 'Bouygues',
    33699 => 'Bouygues',
    337500 => 'Euroinformation Telecom',
    337501 => 'SFR',
    337502 => 'SFR',
    337503 => 'SFR',
    337504 => 'SFR',
    3375050 => 'Euroinformation Telecom',
    3375051 => 'Euroinformation Telecom',
    3375052 => 'Euroinformation Telecom',
    3375053 => 'Euroinformation Telecom',
    3375057 => 'Euroinformation Telecom',
    3375058 => 'Euroinformation Telecom',
    3375059 => 'Sewan communications',
    337506 => 'Orange France',
    3375060 => 'Euroinformation Telecom',
    3375070 => 'Euroinformation Telecom',
    3375071 => 'Netcom Group',
    3375072 => 'Netcom Group',
    3375073 => 'Alphalink',
    3375074 => 'Alphalink',
    3375075 => 'Alphalink',
    3375076 => 'Globalstar Europe',
    3375077 => 'Globalstar Europe',
    3375078 => 'Bouygues',
    3375079 => 'Bouygues',
    337508 => 'SFR',
    337509 => 'SFR',
    33751 => 'Lycamobile',
    337516 => 'SFR',
    337517 => 'Completel',
    337518 => 'Lebara France Limited',
    337519 => 'Lebara France Limited',
    3375202 => 'Prixtel',
    3375203 => 'Prixtel',
    3375204 => 'Prixtel',
    3375205 => 'Prixtel',
    3375206 => 'Prixtel',
    3375207 => 'Prixtel',
    3375208 => 'Prixtel',
    3375209 => 'Prixtel',
    337521 => 'Lebara France Limited',
    337522 => 'Lebara France Limited',
    337523 => 'Lebara France Limited',
    337524 => 'Lebara France Limited',
    337525 => 'Lebara France Limited',
    337526 => 'SFR',
    337527 => 'Lebara France Limited',
    337528 => 'Lebara France Limited',
    337529 => 'Lebara France Limited',
    33753 => 'Lycamobile',
    337540 => 'Lebara France Limited',
    337541 => 'Lebara France Limited',
    337542 => 'Lebara France Limited',
    337543 => 'Prixtel',
    3375430 => 'TDF',
    3375431 => 'Legos',
    3375432 => 'Euroinformation Telecom',
    337544 => 'Lebara France Limited',
    337545 => 'Lebara France Limited',
    337546 => 'Mobiquithings',
    337547 => 'ACN Communications',
    337548 => 'Completel',
    337549 => 'Completel',
    33755 => 'Lebara France Limited',
    3375550 => 'Legos',
    3375551 => 'Legos',
    3375552 => 'Legos',
    3375553 => 'Legos',
    3375554 => 'Legos',
    3375555 => 'Euroinformation Telecom',
    3375556 => 'Intercall',
    3375557 => 'Intercall',
    3375558 => 'Sewan communications',
    3375559 => 'Sewan communications',
    3375560 => 'Prixtel',
    3375561 => 'Prixtel',
    3375562 => 'Prixtel',
    3375563 => 'Prixtel',
    3375564 => 'Prixtel',
    3375565 => 'Sewan communications',
    3375566 => 'Euroinformation Telecom',
    3375567 => 'Euroinformation Telecom',
    3375568 => 'Euroinformation Telecom',
    3375569 => 'Axialys',
    337560 => 'Euroinformation Telecom',
    337561 => 'Euroinformation Telecom',
    337562 => 'Euroinformation Telecom',
    3375630 => 'Euroinformation Telecom',
    3375631 => 'Euroinformation Telecom',
    3375632 => 'Euroinformation Telecom',
    3375633 => 'Euroinformation Telecom',
    3375634 => 'Euroinformation Telecom',
    3375644 => 'SFR',
    3375645 => 'SFR',
    337565 => 'Transatel',
    337566 => 'Transatel',
    337567 => 'Transatel',
    337568 => 'Transatel',
    337569 => 'Transatel',
    3375700 => 'Sewan communications',
    3375701 => 'Mobiweb telecom limited',
    3375702 => 'Mobiweb telecom limited',
    3375703 => 'Mobiweb telecom limited',
    3375704 => 'Mobiweb telecom limited',
    3375705 => 'Mobiweb telecom limited',
    3375706 => 'Nordnet',
    3375707 => 'Keyyo',
    3375708 => 'SFR',
    3375709 => 'SFR',
    3375710 => 'SFR',
    3375711 => 'SFR',
    3375712 => 'SFR',
    3375714 => 'SFR',
    3375715 => 'AIF',
    3375717 => 'Keyyo',
    3375719 => 'Orange France',
    337572 => 'Mobiquithings',
    337573 => 'Mobiquithings',
    337574 => 'Coriolis Telecom',
    337575 => 'Coriolis Telecom',
    3375757 => 'Euroinformation Telecom',
    3375758 => 'Euroinformation Telecom',
    3375759 => 'Twilio Ireland Limited',
    3375760 => 'Twilio Ireland Limited',
    3375763 => 'Euroinformation Telecom',
    3375764 => 'Bouygues',
    3375765 => 'Bouygues',
    3375767 => 'Euroinformation Telecom',
    3375770 => 'SFR',
    3375771 => 'SFR',
    3375772 => 'SFR',
    3375773 => 'SFR',
    3375774 => 'SFR',
    3375777 => 'Euroinformation Telecom',
    3375779 => 'Halys',
    3375786 => 'Orange France',
    3375787 => 'Euroinformation Telecom',
    3375788 => 'BJT',
    3375789 => 'BJT',
    337579 => 'Legos',
    33758 => 'Lycamobile',
    33759 => 'Vectone mobile',
    3376 => 'Bouygues',
    33766 => 'Free Mobile',
    33767 => 'Free Mobile',
    33768 => 'Free Mobile',
    33769 => 'Free Mobile',
    337700 => 'Orange France',
    337701 => 'Orange France',
    337702 => 'Orange France',
    337703 => 'SFR',
    337704 => 'SFR',
    337705 => 'Euroinformation Telecom',
    337706 => 'Euroinformation Telecom',
    337707 => 'Euroinformation Telecom',
    337708 => 'Euroinformation Telecom',
    337709 => 'Euroinformation Telecom',
    337710 => 'Euroinformation Telecom',
    337711 => 'Euroinformation Telecom',
    337712 => 'Euroinformation Telecom',
    337713 => 'SFR',
    337714 => 'SFR',
    3377150 => 'SFR',
    3377151 => 'SFR',
    3377152 => 'SFR',
    3377153 => 'SFR',
    3377154 => 'SFR',
    3377155 => 'Euroinformation Telecom',
    3377156 => 'Euroinformation Telecom',
    3377157 => 'Euroinformation Telecom',
    3377158 => 'Euroinformation Telecom',
    3377159 => 'Euroinformation Telecom',
    337716 => 'Euroinformation Telecom',
    337717 => 'Euroinformation Telecom',
    337718 => 'Euroinformation Telecom',
    3377190 => 'Euroinformation Telecom',
    3377191 => 'Euroinformation Telecom',
    3377192 => 'Euroinformation Telecom',
    3377193 => 'Euroinformation Telecom',
    3377194 => 'Euroinformation Telecom',
    33772 => 'Orange France',
    33773 => 'Syma mobile',
    33774 => 'Syma mobile',
    337750 => 'SFR',
    337751 => 'SFR',
    337752 => 'SFR',
    337753 => 'SFR',
    337754 => 'SFR',
    337755 => 'Mobiquithings',
    337756 => 'Mobiquithings',
    337757 => 'Free Mobile',
    33776 => 'SFR',
    33777 => 'SFR',
    33778 => 'SFR',
    33779 => 'SFR',
    3378 => 'Orange France',
    33780 => 'Afone',
    337807 => 'Lebara France Limited',
    337808 => 'Lebara France Limited',
    337809 => 'Onoff telecom',
    33781 => 'Free Mobile',
    33782 => 'Free Mobile',
    33783 => 'Free Mobile',
    337846 => 'La poste telecom',
    337847 => 'La poste telecom',
    337848 => 'La poste telecom',
    337849 => 'Euroinformation Telecom',
];
