<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    56211 => 'Santiago, Metropolitan Region',
    562198 => 'Santiago, Metropolitan Region',
    5622 => 'Santiago, Metropolitan Region',
    5623 => 'Santiago, Metropolitan Region',
    5626 => 'Santiago, Metropolitan Region',
    5632 => 'Valparaíso',
    5633 => 'Quillota, Valparaíso',
    5634 => 'San Felipe, Valparaíso',
    5635 => 'San Antonio, Valparaíso',
    5641 => 'Concepción, Biobío',
    5642 => 'Chillán, Biobío',
    5643 => 'Los Angeles, Biobío',
    5645 => 'Temuco, Araucanía',
    5651 => 'La Serena, Coquimbo',
    5652 => 'Copiapó, Atacama',
    56530 => 'Ovalle, Coquimbo',
    56531 => 'Ovalle, Coquimbo',
    565320 => 'Ovalle, Coquimbo',
    565321 => 'Ovalle, Coquimbo',
    565322 => 'Ovalle, Coquimbo',
    565323 => 'Ovalle, Coquimbo',
    5653240 => 'Ovalle, Coquimbo',
    5653241 => 'Ovalle, Coquimbo',
    5653242 => 'Ovalle, Coquimbo',
    5653243 => 'Ovalle, Coquimbo',
    5653244 => 'Ovalle, Coquimbo',
    56532452 => 'Ovalle, Coquimbo',
    56532453 => 'Ovalle, Coquimbo',
    56532454 => 'Ovalle, Coquimbo',
    56532455 => 'Ovalle, Coquimbo',
    56532456 => 'Ovalle, Coquimbo',
    56532457 => 'Ovalle, Coquimbo',
    56532458 => 'Ovalle, Coquimbo',
    56532459 => 'Ovalle, Coquimbo',
    5653246 => 'Ovalle, Coquimbo',
    5653247 => 'Ovalle, Coquimbo',
    5653248 => 'Ovalle, Coquimbo',
    5653249 => 'Ovalle, Coquimbo',
    565325 => 'Ovalle, Coquimbo',
    565326 => 'Ovalle, Coquimbo',
    565327 => 'Ovalle, Coquimbo',
    565328 => 'Ovalle, Coquimbo',
    565329 => 'Ovalle, Coquimbo',
    56533 => 'Ovalle, Coquimbo',
    56534 => 'Ovalle, Coquimbo',
    56535 => 'Ovalle, Coquimbo',
    56536 => 'Ovalle, Coquimbo',
    56537 => 'Ovalle, Coquimbo',
    56538 => 'Ovalle, Coquimbo',
    56539 => 'Ovalle, Coquimbo',
    5655 => 'Antofagasta',
    5657 => 'Iquique, Tarapacá',
    5658 => 'Arica, Arica and Parinacota',
    5661 => 'Punta Arenas, Magallanes and Antártica Chilena',
    5663 => 'Valdivia, Los Ríos',
    5664 => 'Osorno, Los Lagos',
    5665 => 'Puerto Montt, Los Lagos',
    5667 => 'Coyhaique, Aisén',
    5671 => 'Talca, Maule',
    5672 => 'Rancagua, O\'Higgins',
    5673 => 'Linares, Maule',
    5675 => 'Curicó, Maule',
];
