<?php

namespace Longman\TelegramBot\Entities\ChatMember;

use Longman\TelegramBot\Entities\User;

/**
 * Interface ChatMember
 *
 * @method string getStatus() The member's status in the chat
 * @method User   getUser()   Information about the user
 */
interface ChatMember
{
    //
}
