<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    29821 => 'Faroese Telecom',
    29822 => 'Faroese Telecom',
    29823 => 'Faroese Telecom',
    29824 => 'Faroese Telecom',
    29825 => 'Faroese Telecom',
    29826 => 'Faroese Telecom',
    29827 => 'Faroese Telecom',
    29828 => 'Faroese Telecom',
    29829 => 'Faroese Telecom',
    2985 => 'Vodafone',
    2987 => 'Vodafone',
    29878 => 'Faroese Telecom',
    29879 => 'Faroese Telecom',
    29891 => 'Faroese Telecom',
    29896 => 'Faroese Telecom',
];
