<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    822 => '서울',
    8231 => '경기',
    8232 => '인천',
    8233 => '강원',
    8241 => '충남',
    8242 => '대전',
    8243 => '충북',
    8244 => '세종',
    8251 => '부산',
    8252 => '울산',
    8253 => '대구',
    8254 => '경북',
    8255 => '경남',
    8261 => '전남',
    8262 => '광주',
    8263 => '전북',
    8264 => '제주',
];
