<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    67654 => 'Toko Wireless',
    676554 => 'Toko Wireless',
    676555 => 'Toko Wireless',
    676556 => 'Toko Wireless',
    67668 => 'Digicel',
    67670 => 'Digicel',
    67672 => 'U-Call Tonga',
    67673 => 'U-Call Tonga',
    67674 => 'U-Call Tonga',
    67675 => 'U-Call Tonga',
    67676 => 'U-Call Tonga',
    67677 => 'U-Call Tonga',
    67678 => 'U-Call Tonga',
    67679 => 'U-Call Tonga',
    67684 => 'Digicel',
    67686 => 'Digicel',
    67687 => 'Digicel',
    67688 => 'Digicel',
    67689 => 'Digicel',
    6769 => 'Digicel',
];
