<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    856202 => 'ETL',
    856203 => 'ETL',
    856205 => 'Lao Telecom',
    856207 => 'Beeline',
    856208 => 'Best Telecom',
    856209 => 'Unitel',
    856302 => 'ETL',
    856304 => 'Unitel',
];
