<?php
/*
* File:     ImapBadRequestException.php
* Category: Exception
* Author:   S. Janaczek
* Created:  08.09.22 08:39
* Updated:  -
*
* Description:
*  -
*/

namespace Webklex\PHPIMAP\Exceptions;

use \Exception;

/**
 * Class GetMessagesFailedException
 *
 * @package Webklex\PHPIMAP\Exceptions
 */
class ImapBadRequestException extends Exception {

}
