<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    23762 => 'Camtel',
    23764 => 'Orange',
    237650 => 'MTN Cameroon',
    237651 => 'MTN Cameroon',
    237652 => 'MTN Cameroon',
    237653 => 'MTN Cameroon',
    237654 => 'MTN Cameroon',
    237655 => 'Orange',
    237656 => 'Orange',
    237657 => 'Orange',
    237658 => 'Orange',
    237659 => 'Orange',
    23766 => 'NEXTTEL',
    23767 => 'MTN Cameroon',
    237680 => 'MTN Cameroon',
    237681 => 'MTN Cameroon',
    237682 => 'MTN Cameroon',
    237683 => 'MTN Cameroon',
    237684 => 'NEXTTEL',
    237685 => 'NEXTTEL',
    237686 => 'Orange',
    237687 => 'Orange',
    237688 => 'Orange',
    237689 => 'Orange',
    23769 => 'Orange',
];
