<?php
namespace Aws\SecurityHub\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS SecurityHub** service.
 */
class SecurityHubException extends AwsException {}
