<?php
// This file was auto-generated from sdk-root/src/data/verifiedpermissions/2021-12-01/paginators-1.json
return [ 'pagination' => [ 'ListIdentitySources' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'identitySources', ], 'ListPolicies' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'policies', ], 'ListPolicyStores' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'policyStores', ], 'ListPolicyTemplates' => [ 'input_token' => 'nextToken', 'output_token' => 'nextToken', 'limit_key' => 'maxResults', 'result_key' => 'policyTemplates', ], ],];
