<?php
namespace Aws\MedicalImaging\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Health Imaging** service.
 */
class MedicalImagingException extends AwsException {}
