<?php
namespace Aws\IoTWireless\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS IoT Wireless** service.
 */
class IoTWirelessException extends AwsException {}
