<?php
namespace Aws\BedrockDataAutomationRuntime\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Runtime for Amazon Bedrock Data Automation** service.
 */
class BedrockDataAutomationRuntimeException extends AwsException {}
