<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    233302 => 'Accra',
    233303 => 'Tema',
    2333035 => 'Ada',
    233307 => 'Greater Accra Region',
    233308 => 'Greater Accra Region',
    2333120 => 'Takoradi',
    2333121 => 'Axim',
    2333122 => 'Elubo',
    2333123 => 'Tarkwa',
    2333124 => 'Asankragwa',
    2333125 => 'Samreboi',
    2333126 => 'Enchi',
    233317 => 'Western Region',
    233318 => 'Western Region',
    2333220 => 'Kumasi',
    2333221 => 'Konongo',
    2333222 => 'Ashanti Mampong',
    2333223 => 'Ejura',
    2333224 => 'Bekwai',
    2333225 => 'Obuasi',
    233327 => 'Ashanti Region',
    233328 => 'Ashanti Region',
    2333320 => 'Swedru',
    2333321 => 'Cape Coast',
    2333322 => 'Dunkwa',
    2333323 => 'Winneba',
    233337 => 'Central Region',
    233338 => 'Central Region',
    2333420 => 'Koforidua',
    2333421 => 'Nsawam',
    2333423 => 'Mpraeso',
    2333424 => 'Donkorkrom',
    2333425 => 'Suhum',
    2333426 => 'Asamankese',
    2333427 => 'Akuapim Mampong',
    2333428 => 'Aburi',
    23334292 => 'Akim Oda',
    2333430 => 'Akosombo',
    2333431 => 'Nkawkaw',
    233347 => 'Eastern Region',
    233348 => 'Eastern Region',
    2333520 => 'Sunyani',
    2333521 => 'Bechem',
    2333522 => 'Berekum',
    2333523 => 'Dormaa Ahenkro',
    2333524 => 'Wenchi',
    2333525 => 'Techiman',
    2333526 => 'Atebubu',
    2333527 => 'Yeji',
    233357 => 'Brong-Ahafo Region',
    233358 => 'Brong-Ahafo Region',
    2333620 => 'Ho',
    2333621 => 'Amedzofe',
    2333622 => 'Hohoe',
    2333623 => 'Kpandu',
    2333624 => 'Kete-Krachi',
    2333625 => 'Denu/Aflao',
    2333626 => 'Keta/Akatsi',
    233367 => 'Volta Region',
    233368 => 'Volta Region',
    2333720 => 'Tamale',
    2333721 => 'Walewale',
    2333722 => 'Buipe',
    2333723 => 'Damongo',
    2333724 => 'Yendi',
    2333725 => 'Bole',
    2333726 => 'Salaga',
    233377 => 'Northern Region',
    233378 => 'Northern Region',
    2333820 => 'Bolgatanga',
    2333821 => 'Navrongo',
    2333822 => 'Bawku',
    233387 => 'Upper East Region',
    233388 => 'Upper East Region',
    233392 => 'Wa',
    233397 => 'Upper West Region',
    233398 => 'Upper West Region',
];
