<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    673228 => 'DSTCom',
    673229 => 'DSTCom',
    67371 => 'UNN',
    67372 => 'UNN',
    67373 => 'UNN',
    67374 => 'UNN',
    67376 => 'UNN',
    67377 => 'UNN',
    67379 => 'UNN',
    67381 => 'UNN',
    67382 => 'UNN',
    67383 => 'UNN',
    67384 => 'UNN',
    67386 => 'UNN',
    67387 => 'UNN',
    67388 => 'UNN',
    67389 => 'UNN',
];
