<?php
namespace Aws\CloudHSMV2\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS CloudHSM V2** service.
 */
class CloudHSMV2Exception extends AwsException {}
