<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    962262 => 'Mafraq',
    962263 => 'Jarash',
    962264 => 'Ajloun',
    962265 => 'Irbid',
    962266 => 'Mafraq',
    962267 => 'Jarash',
    962268 => 'Ajloun',
    962269 => 'Irbid',
    96227 => 'Irbid',
    962320 => 'Aqaba',
    962321 => 'Ma’an',
    962322 => 'Tafileh',
    962323 => 'Karak',
    962324 => 'Aqaba',
    962325 => 'Maan',
    9623260 => 'Tafileh',
    9623262 => 'Southern Region',
    962327 => 'Karak',
    962530 => 'Zarqa',
    962531 => 'Madaba',
    962532 => 'Madaba',
    962533 => 'Balqa',
    962534 => 'Balqa',
    962535 => 'Balqa',
    962536 => 'Zarqa',
    962537 => 'Zarqa',
    962538 => 'Zarqa',
    962539 => 'Zarqa',
    962620 => 'Amman',
    962622 => 'Greater Amman',
    962625 => 'Amman',
    96263 => 'Amman',
    96264 => 'Amman',
    962647 => 'Greater Amman',
    96265 => 'Amman',
];
