<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    373210 => 'Григориополь',
    373215 => 'Дубэсарь',
    373216 => 'Каменка',
    373219 => 'Днестровск',
    37322 => 'Кишинэу',
    373230 => 'Сорока',
    373231 => 'Бэлць',
    373235 => 'Орхей',
    373236 => 'Унгень',
    373237 => 'Стрэшень',
    373241 => 'Чимишлия',
    373242 => 'Штефан Водэ',
    373243 => 'Кэушень',
    373244 => 'Кэлэрашь',
    373246 => 'Единец',
    373247 => 'Бричень',
    373248 => 'Криулень',
    373249 => 'Глодень',
    373250 => 'Флорешть',
    373251 => 'Дондушень',
    373252 => 'Дрокия',
    373254 => 'Резина',
    373256 => 'Рышкань',
    373258 => 'Теленешть',
    373259 => 'Фэлешть',
    373262 => 'Сынжерей',
    373263 => 'Леова',
    373264 => 'Ниспорень',
    373265 => 'Анений Ной',
    373268 => 'Яловень',
    373269 => 'Хынчешть',
    373271 => 'Окница',
    373272 => 'Шолдэнешть',
    373273 => 'Кантемир',
    373291 => 'Чадыр-Лунга',
    373293 => 'Вулкэнешть',
    373294 => 'Тараклия',
    373297 => 'Басарабяска',
    373298 => 'Комрат',
    373299 => 'Кагул',
    37353 => 'Тираспол',
    373552 => 'Бендер',
    373555 => 'Рыбница',
    373557 => 'Слобозия',
];
