<?php
namespace Aws\MarketplaceDeployment\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Marketplace Deployment Service** service.
 */
class MarketplaceDeploymentException extends AwsException {}
