<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    24544320 => 'Bissau',
    24544321 => 'Bissau',
    24544322 => 'St. Luzia',
    24544325 => 'Brá',
    24544331 => 'Mansôa',
    24544332 => 'Bissora',
    24544334 => 'Mansaba',
    24544335 => 'Farim',
    24544341 => 'Bafatá',
    24544342 => 'Bambadinca',
    24544351 => 'Gabu',
    24544352 => 'Sonaco',
    24544353 => 'Pirada',
    24544354 => 'Pitche',
    24544370 => 'Buba',
    24544391 => 'Canchungo',
    24544392 => 'Cacheu',
    24544393 => 'S. Domingos',
    24544394 => 'Bula',
    24544396 => 'Ingoré',
    24544397 => 'Bigene',
];
