<?php
namespace Aws\ComputeOptimizer\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Compute Optimizer** service.
 */
class ComputeOptimizerException extends AwsException {}
