<?php
namespace Aws\MPA\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Multi-party Approval** service.
 */
class MPAException extends AwsException {}
