<?php
// This file was auto-generated from sdk-root/src/data/application-signals/2024-04-15/paginators-1.json
return [ 'pagination' => [ 'ListServiceDependencies' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ServiceDependencies', ], 'ListServiceDependents' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ServiceDependents', ], 'ListServiceLevelObjectiveExclusionWindows' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ExclusionWindows', ], 'ListServiceLevelObjectives' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'SloSummaries', ], 'ListServiceOperations' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ServiceOperations', ], 'ListServices' => [ 'input_token' => 'NextToken', 'output_token' => 'NextToken', 'limit_key' => 'MaxResults', 'result_key' => 'ServiceSummaries', ], ],];
