<?php

/**
 * This file has been @generated by a phing task by {@link GeneratePhonePrefixData}.
 * See [README.md](README.md#generating-data) for more information.
 *
 * Pull requests changing data in these files will not be accepted. See the
 * [FAQ in the README](README.md#problems-with-invalid-numbers] on how to make
 * metadata changes.
 *
 * Do not modify this file directly!
 */

return  [
    97790 => 'NCell',
    977960 => 'STM Telecom',
    977961 => 'Smart Telecom',
    977962 => 'Smart Telecom',
    977963 => 'NSTPL',
    977970 => 'NCell',
    977972 => 'UTL',
    977974 => 'NDCL',
    977975 => 'NDCL',
    977976 => 'Nepal Telecom',
    977980 => 'NCell',
    977981 => 'NCell',
    977982 => 'NCell',
    977984 => 'Nepal Telecom',
    977985 => 'Nepal Telecom',
    977986 => 'Nepal Telecom',
    977988 => 'Smart Telecom',
];
