<?php
namespace Aws\PcaConnectorAd\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **PcaConnectorAd** service.
 */
class PcaConnectorAdException extends AwsException {}
