<?php

declare(strict_types=1);
/**
 * Locale data file
 * This file has been @generated from Locale data
 * Do not modify or use this file directly!
 * @internal
 */
return [
    'AO' => 'Aŋgɔ́la',
    'AR' => 'Ajɛntîn',
    'BF' => 'Mbulukína Fásɔ',
    'BI' => 'Mbulundí',
    'BJ' => 'Mbɛnɛ̂ŋ',
    'BO' => 'Mbɔlivî',
    'BR' => 'Mbɛlazîl',
    'BW' => 'Mbɔtswána',
    'CA' => 'Kanadâ',
    'CD' => 'Kɔ́ŋgɔ-Kinshása',
    'CG' => 'Kɔ́ŋgɔ-Mbɛlazavîl',
    'CH' => 'Sẅísɛ',
    'CI' => 'Kɔ́t Ndivwâ',
    'CL' => 'Cíllɛ',
    'CM' => 'Kamɛlûn',
    'CN' => 'Shîn',
    'CO' => 'Kɔllɔmbî',
    'CU' => 'Kúba',
    'DE' => 'Njáman',
    'DJ' => 'Njimbúti',
    'DZ' => 'Aljɛlî',
    'EC' => 'Ɛkwandɔ̂',
    'EG' => 'Ɛjíptɛ',
    'ER' => 'Ɛlitɛlɛ́ya',
    'ES' => 'Ɛspániya',
    'ET' => 'Ɛtiyɔpî',
    'FR' => 'Fɛlánci',
    'GA' => 'Ŋgabɔ̂ŋ',
    'GH' => 'Ŋgána',
    'GM' => 'Ŋgambî',
    'GN' => 'Ŋginɛ̂',
    'GQ' => 'Ŋginɛ̂ Ɛkwatɔliyâl',
    'GR' => 'Ŋgɛlɛ̂k',
    'GW' => 'Ŋginɛ̂ Mbisáwu',
    'IL' => 'Islayɛ̂l',
    'IN' => 'Ándɛ',
    'IQ' => 'Ilâk',
    'IT' => 'Italî',
    'JP' => 'Japɔ̂n',
    'KE' => 'Kɛ́nya',
    'KM' => 'Kɔmɔ́lɔshi',
    'LR' => 'Libɛrî',
    'LS' => 'Lɛsɔ́tɔ',
    'LY' => 'Libî',
    'MA' => 'Mɔlɔ̂k',
    'MG' => 'Mándaŋgasɛkâ',
    'ML' => 'Malî',
    'MR' => 'Mɔlitanî',
    'MW' => 'Maláwi',
    'MX' => 'Mɛksîk',
    'MZ' => 'Mɔzambîk',
    'NA' => 'Namimbî',
    'NE' => 'Nijɛ̂',
    'NG' => 'Ninjɛliyâ',
    'NO' => 'Nɔlɛvɛ́jɛ',
    'PE' => 'Pɛlû',
    'RE' => 'Lɛ́uniyɔ̂n',
    'RS' => 'Sɛlɛbî',
    'RU' => 'Lusî',
    'RW' => 'Luwánda',
    'SC' => 'Pɛsɛ́shɛl',
    'SD' => 'Sundân',
    'SL' => 'Siyɛ́la Lɛɔ̂n',
    'SN' => 'Sɛnɛgâl',
    'SO' => 'Sɔmalî',
    'ST' => 'Sáwɔŋ Tɔmɛ́ nɛ́ Pɛlínsipɛ',
    'SZ' => 'Swazilân',
    'TD' => 'Cât',
    'TG' => 'Tɔ́ŋgɔ',
    'TN' => 'Tunizî',
    'TZ' => 'Tanzanî',
    'UG' => 'Uŋgánda',
    'VE' => 'Vɛnɛzwɛ́la',
    'YT' => 'Mayɔ̂t',
    'ZM' => 'Zambî',
    'ZW' => 'Zimbámbwɛ',
];
