<?php
namespace Aws\BedrockAgentCore\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Bedrock AgentCore Data Plane Fronting Layer** service.
 */
class BedrockAgentCoreException extends AwsException {}
