<?php
namespace Aws\LocationService\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Location Service** service.
 */
class LocationServiceException extends AwsException {}
