<?php
namespace Aws\KeyspacesStreams\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Keyspaces Streams** service.
 */
class KeyspacesStreamsException extends AwsException {}
