<?php
namespace Aws\MarketplaceAgreement\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **AWS Marketplace Agreement Service** service.
 */
class MarketplaceAgreementException extends AwsException {}
