<?php
namespace Aws\EKS\Exception;

use Aws\Exception\AwsException;

/**
 * Represents an error interacting with the **Amazon Elastic Container Service for Kubernetes** service.
 */
class EKSException extends AwsException {}
